###############################################PLAUSIBILITY ANALYSES 2016####################################################
#### Below is the code used to compute the main and supplementray analyses for the manuscript entitled "Investigating
#### the Use of World Knowledge During On-line Comprehension in Adults with Autism Spectrum Disorder".

#### For the analyses reported in the manuscript, age was included as a fixed effect in each linear mixed effect model. 
#### This was because there was a difference on average between the TD and ASD readers age. No reliable effects of age were 
#### found for any model, however, age remained in each model as a control. In order to assure anonymity of our
#### participants, we have excluded age information from the data provided. However. the syntax used to compute each model still
#### includes age, to allow interested readers to see the final model run for each measure, following the removal of parameters
#### from the random structure if there were convergence issues. Therefore, if you wish to run this script, prior to running a
#### linear mixed effects model, the variable labelled CENTRED_AGE should be deleted (fixed effect and random structure). As a 
#### result, the output will differ slightly from that reported in the manuscript. 

#### This data has been cleaned in dataviewer and this resulted in a loss of 3.49% of original data.
#### Condition labels; 1 = Anomalous, 2 = Implausible, 3 = Plausible

library(plyr)
library(sm)
library(lattice)
library(languageR)
library(lme4)
library(MASS)
citation("MASS")
library(effects)
library(ggplot2)
citation("lme4")
library(lmerTest)
citation("lmerTest")

#Importing raw data files
IA_RAW <- read.delim("IA_REPORT_JADD_5Nov2016.txt", stringsAsFactors=FALSE) #Interest area report
FIX_RAW <- read.delim("FIX_REPORT_JADD_5Nov2016.txt", stringsAsFactors=FALSE) #Fixaiton report
TRIAL_RAW <- read.delim("TRIAL_REPORT_JADD_5Nov2016.txt", stringsAsFactors=FALSE) #Trial report
WEIRD_RAW <-read.delim("weird_trial_JADD_5Nov2016.txt", stringsAsFactors=FALSE) #list of 'weird' trials to be deleted e.g., tracker loss

#Excluding two participants who scored low on the CELF 
IA = IA_RAW[IA_RAW$RECORDING_SESSION_LABEL != "ex23",]
IA = IA[IA$RECORDING_SESSION_LABEL != "ex24",]

FIX = FIX_RAW[FIX_RAW$RECORDING_SESSION_LABEL != "ex23",]
FIX = FIX[FIX$RECORDING_SESSION_LABEL != "ex24",]

TRIAL = TRIAL_RAW[TRIAL_RAW$RECORDING_SESSION_LABEL != "ex23",]
TRIAL = TRIAL[TRIAL$RECORDING_SESSION_LABEL != "ex24",]

WEIRD = WEIRD_RAW 

#####################################################################################
######################GLOBAL EYE MOVEMENT ANALYSIS###################################
##Using the trial report to retrieve mean fixation duration, fixation count and trial duration data.

##Checking and sorting out the structure
str(TRIAL)
TRIAL$RECORDING_SESSION_LABEL = as.factor(TRIAL$RECORDING_SESSION_LABEL)
TRIAL$condition_no = as.factor(TRIAL$condition_no)
TRIAL$stimulus_no = as.factor(TRIAL$stimulus_no)
TRIAL$AVERAGE_FIXATION_DURATION = as.numeric(TRIAL$AVERAGE_FIXATION_DURATION)
TRIAL$FIXATION_COUNT = as.numeric(TRIAL$FIXATION_COUNT)
TRIAL$DURATION = as.numeric(TRIAL$DURATION)
TRIAL$stimuli_filler = as.factor(TRIAL$stimuli_filler)
str(TRIAL)

#Removing fillers (F) and practice (P) trials
TRIAL = TRIAL[TRIAL$stimuli_filler == "S",]
TRIAL = droplevels(TRIAL)
unique(TRIAL$stimuli_filler)
unique(TRIAL$practice)

str(TRIAL$stimulus_no) # 36 stimuli
str(TRIAL$condition) # 3 conditions

##Adding a column to identify participants groups (ASD vs. TD)
TRIAL$GROUP = TRIAL$RECORDING_SESSION_LABEL 
TRIAL$GROUP = revalue(TRIAL$GROUP, c("ex1"="ASD", "ex2"="ASD", "ex3" = "ASD", "ex4" = "ASD", "ex5" = "ASD", "ex6" = "ASD","ex7" = "ASD", "ex8" = "ASD", "ex9" = "ASD", "ex10" = "ASD", "ex11" = "ASD", "ex12" = "ASD", "ex13" = "ASD", "ex14" = "ASD", "ex15" = "ASD", "ex16" = "ASD", "ex17" = "ASD", "ex18" = "ASD","ex19" = "ASD", "ex20" = "ASD", "ex21" = "ASD", "ex22" = "ASD",
                                     "td1" = "TD", "td2" = "TD", "td3" = "TD", "td4" = "TD", "td5" = "TD", "td6" = "TD", "td7" = "TD", "td8" = "TD", "td9" = "TD", "td10" = "TD", "td11" = "TD", "td12" = "TD", "td13" = "TD", "td14" = "TD", "td15" = "TD", "td16" = "TD", "td17" = "TD", "td18" = "TD", "td19" = "TD", "td20" = "TD", "td21" = "TD", "td22" = "TD", "td23" = "TD", "td24" = "TD"))
str(TRIAL$GROUP)

##Removing weird trials from the trial report
TRIAL$PPTRIAL=paste(TRIAL$RECORDING_SESSION_LABEL, TRIAL$TRIAL_INDEX, sep = "") #making a unique identifier in both the trial report and weird file
head(TRIAL)
WEIRD$PPTRIAL = paste(WEIRD$RECORDING_SESSION_LABEL, WEIRD$TRIAL_INDEX, sep = "") 
head(WEIRD)
WEIRD$MARKS <- 1 #assign marks of 1 to all the weird trials (that I will delete) so they can be easily identified in the trial report
TRIAL_WEIRD_MARKED <- merge(WEIRD, TRIAL, by = "PPTRIAL", all.y=TRUE) 
head(TRIAL_WEIRD_MARKED) #check that the merge worked
TRIAL_PLAUS_WEIRD_DEL <- TRIAL_WEIRD_MARKED[is.na(TRIAL_WEIRD_MARKED$MARKS), ] #Delete the trials marked with 1
(100/1657)*47 #2.84% of data removed (1657-1610) #47 trials removed

#removing repeated columns and returning column names to original
TRIAL_PLAUS_WEIRD_DEL <- TRIAL_PLAUS_WEIRD_DEL[,-(2:4),drop=FALSE]
names(TRIAL_PLAUS_WEIRD_DEL)[names(TRIAL_PLAUS_WEIRD_DEL)=="RECORDING_SESSION_LABEL.y"] <- "RECORDING_SESSION_LABEL"
head(TRIAL_PLAUS_WEIRD_DEL)

#####removing trials when ppts blinked in the target
pp_blinks <- FIX[FIX$stimuli_filler == "S" & FIX$CURRENT_FIX_INTEREST_AREA_INDEX== 3 & FIX$CURRENT_FIX_BLINK_AROUND!= "NONE",] ##Creating a file that contains the instances when a participant blinked whilst fixating the target region (from fixation report)
pp_blinks$CURRENT_FIX_INTEREST_AREA_INDEX ##checking it worked 
pp_blinks$CURRENT_FIX_BLINK_AROUND ##checking it worked 
pp_blinks$stimuli_filler ##checking it worked 

##Removing trials when there was a blink using the same method as above (for weird trials)
pp_blinks$PPTRIAL = paste(pp_blinks$RECORDING_SESSION_LABEL, pp_blinks$TRIAL_INDEX, sep = "") 
pp_blinks$PPTRIAL
pp_blinks_list <- as.data.frame(pp_blinks$PPTRIAL) #dataframe including only this info
names(pp_blinks_list)[names(pp_blinks_list)=="pp_blinks$PPTRIAL"] <- "PPTRIAL"
pp_blinks_list$MARKS <- 1
pp_blinks_list = unique(pp_blinks_list) ##removing duplicates - 148
TRIAL_BLINK_MARKED <- merge(pp_blinks_list, TRIAL_PLAUS_WEIRD_DEL, by = "PPTRIAL", all.y=TRUE)
head(TRIAL_BLINK_MARKED)
TRIAL_CLEAN <- TRIAL_BLINK_MARKED[is.na(TRIAL_BLINK_MARKED$MARKS), ]
##1610-1469 = 100/1610*141 - 8.76% of data loss 
head(TRIAL_CLEAN)
##TOTAL AMOUNT OF DATA REMOVED FROM THIS CLEANING = 8.76+2.78 = 11.54%

####################################Average Fixation Duration###################################

TRIAL_AFD = TRIAL_CLEAN ##making a seperate file for the AFD analysis
TRIAL_AFD <- TRIAL_AFD[!(is.na(TRIAL_AFD$AVERAGE_FIXATION_DURATION)),] ##deleting any missing data points
str(TRIAL_AFD)

##checking distribution
sm.density.compare(TRIAL_AFD$AVERAGE_FIXATION_DURATION, TRIAL_AFD$GROUP)
legend("topright", levels(TRIAL_AFD$GROUP), fill=2+(0:nlevels(TRIAL_AFD$GROUP)))

#####Removing outliers >2.5sd based on group means for each condition
mean.matrix.TRIAL_AFD = tapply(TRIAL_AFD$AVERAGE_FIXATION_DURATION, list(TRIAL_AFD$GROUP,TRIAL_AFD$condition_no), mean, na.rm = TRUE)
mean.matrix.TRIAL_AFD
sd.matrix.TRIAL_AFD = tapply(TRIAL_AFD$AVERAGE_FIXATION_DURATION, list(TRIAL_AFD$GROUP,TRIAL_AFD$condition_no), sd,na.rm = TRUE)
sd.matrix.TRIAL_AFD
nr = nrow(TRIAL_AFD)
for(i in 1:nr){TRIAL_AFD$mean.sc[i] = mean.matrix.TRIAL_AFD[TRIAL_AFD$GROUP[i],TRIAL_AFD$condition_no[i]]}
for(i in 1:nr){TRIAL_AFD$sd.sc[i] = sd.matrix.TRIAL_AFD[TRIAL_AFD$GROUP[i],TRIAL_AFD$condition_no[i]]}
for(i in 1:nr) {TRIAL_AFD$zscore[i] = (TRIAL_AFD$AVERAGE_FIXATION_DURATION[i] - TRIAL_AFD$mean.sc[i])/TRIAL_AFD$sd.sc[i]}
#sink("TRIAL_AFD_OUTLIERS.txt") ##these three lines of code save outliers that are removed to file TRIAL_AFD_OUTLIERS.txt
#TRIAL_AFD[TRIAL_AFD$zscore > 2.5,] ##feel free to use this, but it is not necessary, it is only for my own records 
#sink()
TRIAL_AFD_CLEAN = TRIAL_AFD[abs(TRIAL_AFD$zscore) < 2.5,]
TRIAL_AFD_CLEAN$zscore
##1468-1444= 24 = 100/1468*24 = 1.63% removed
sm.density.compare(TRIAL_AFD_CLEAN$AVERAGE_FIXATION_DURATION, TRIAL_AFD_CLEAN$GROUP)
legend("topright", levels(TRIAL_AFD_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_AFD_CLEAN$GROUP)))
##that seems to do the job - ASD data not normal - will check distribution of residuals prior to getting model output

## visualising data with QQ plots
qqnorm(TRIAL_AFD_CLEAN$AVERAGE_FIXATION_DURATION)
qqmath(~AVERAGE_FIXATION_DURATION|GROUP, data = TRIAL_AFD_CLEAN)
qqmath(~AVERAGE_FIXATION_DURATION|RECORDING_SESSION_LABEL, data = TRIAL_AFD_CLEAN)##for random factors
qqmath(~AVERAGE_FIXATION_DURATION|stimulus_no, data = TRIAL_AFD_CLEAN)##for random factors
##data looks pretty normal with QQ plots

##log transform data for analysis
##this data does not need log transforming, but a number of other measures (analysed later) do, and so all measures are transformed to be consistent
TRIAL_AFD_CLEAN$logAFD  = log(TRIAL_AFD_CLEAN$AVERAGE_FIXATION_DURATION) 
sm.density.compare(TRIAL_AFD_CLEAN$logAFD, TRIAL_AFD_CLEAN$GROUP)
legend("topright", levels(TRIAL_AFD_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_AFD_CLEAN$GROUP)))
qqmath(~logAFD|GROUP, data = TRIAL_AFD_CLEAN)
qqmath(~logAFD, data = TRIAL_AFD_CLEAN)
qqmath(~logAFD|RECORDING_SESSION_LABEL, data = TRIAL_AFD_CLEAN)##for random factors when log transformed
qqmath(~logAFD|stimulus_no, data = TRIAL_AFD_CLEAN)##for random factors when log transformed
##Below I check whether the residuals are normally distributed after running the lme

###lme
matrix = rbind(c(-.5, 0, .5),#setting up contrasts to compare plaus against anomalous
               c(0,-.5,.5)) #setting up contrasts to compare plaus against implausible
matrix <- ginv(matrix) #inversing contrast matrix for analysis
contrasts(TRIAL_AFD_CLEAN$condition_no) = matrix
contrasts(TRIAL_AFD_CLEAN$GROUP) <- contr.sdif(2)
lmerAFD = lmer(logAFD ~ GROUP*condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TRIAL_AFD_CLEAN)                                                                                                            
qqnorm(resid(lmerAFD)) ##distribution of residuals across groups with QQ plot
sm.density.compare(resid(lmerAFD), TRIAL_AFD_CLEAN$GROUP) ##although raw ASD data not normal, the residuals are normally distributed - should be able to trust this analysis
sm.density(resid(lmerAFD)) ##distribution of residuals across groups with density plot
summary(lmerAFD) 
plot(allEffects(lmerAFD))

##descriptives 
AFD.GROUP_MEAN =tapply(TRIAL_AFD_CLEAN$AVERAGE_FIXATION_DURATION, list(TRIAL_AFD_CLEAN$GROUP, TRIAL_AFD_CLEAN$condition_no), mean, na.rm = TRUE)
AFD.GROUP_SD =tapply(TRIAL_AFD_CLEAN$AVERAGE_FIXATION_DURATION, list(TRIAL_AFD_CLEAN$GROUP, TRIAL_AFD_CLEAN$condition_no), sd, na.rm = TRUE)

####################################Average Fixation Count###################################

TRIAL_AFC = TRIAL_CLEAN[TRIAL_CLEAN$FIXATION_COUNT >0,] ##new data file just for AFC data
TRIAL_AFC <- TRIAL_AFC[!(is.na(TRIAL_AFC$FIXATION_COUNT)),] ##deleting any missing data points

str(TRIAL_AFC)

sm.density.compare(TRIAL_AFC$FIXATION_COUNT, TRIAL_AFC$GROUP)
legend("topright", levels(TRIAL_AFC$GROUP), fill=2+(0:nlevels(TRIAL_AFC$GROUP)))

#####removing data points >2.5sd from group/condition mean
mean.matrix.TRIAL_AFC = tapply(TRIAL_AFC$FIXATION_COUNT, list(TRIAL_AFC$GROUP,TRIAL_AFC$condition_no), mean, na.rm = TRUE)
mean.matrix.TRIAL_AFC
sd.matrix.TRIAL_AFC = tapply(TRIAL_AFC$FIXATION_COUNT, list(TRIAL_AFC$GROUP,TRIAL_AFC$condition_no), sd,na.rm = TRUE)
sd.matrix.TRIAL_AFC
nr = nrow(TRIAL_AFC)
for(i in 1:nr){TRIAL_AFC$mean.sc[i] = mean.matrix.TRIAL_AFC[TRIAL_AFC$GROUP[i],TRIAL_AFC$condition_no[i]]}
for(i in 1:nr){TRIAL_AFC$sd.sc[i] = sd.matrix.TRIAL_AFC[TRIAL_AFC$GROUP[i],TRIAL_AFC$condition_no[i]]}
for(i in 1:nr) {TRIAL_AFC$zscore[i] = (TRIAL_AFC$FIXATION_COUNT[i] - TRIAL_AFC$mean.sc[i])/TRIAL_AFC$sd.sc[i]}
#sink("TRIAL_AFC_OUTLIERS.txt")
#TRIAL_AFC[TRIAL_AFC$zscore > 2.5,]
#sink()
TRIAL_AFC_CLEAN = TRIAL_AFC[abs(TRIAL_AFC$zscore) < 2.5,]
TRIAL_AFC_CLEAN$zscore
sm.density.compare(TRIAL_AFC_CLEAN$FIXATION_COUNT, TRIAL_AFC_CLEAN$GROUP)
legend("topright", levels(TRIAL_AFC_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_AFC_CLEAN$GROUP)))
###distribution looks better, lost 1468-1423 = 45 = 100/1468*43 2.92% of data

##visualising data with QQ plots before and after log transformation
qqnorm(TRIAL_AFC_CLEAN$FIXATION_COUNT)
qqmath(~FIXATION_COUNT|GROUP, data = TRIAL_AFC_CLEAN)
qqmath(~FIXATION_COUNT|RECORDING_SESSION_LABEL, data = TRIAL_AFC_CLEAN) ##for random factors
qqmath(~FIXATION_COUNT|stimulus_no, data = TRIAL_AFC_CLEAN) ##for random factors
TRIAL_AFC_CLEAN$logAFC  = log(TRIAL_AFC_CLEAN$FIXATION_COUNT) ##log transform
qqmath(~logAFC|GROUP, data = TRIAL_AFC_CLEAN)
qqmath(~logAFC, data = TRIAL_AFC_CLEAN)
qqmath(~logAFC|RECORDING_SESSION_LABEL, data = TRIAL_AFC_CLEAN)##for random factors when log transformed
qqmath(~logAFC|stimulus_no, data = TRIAL_AFC_CLEAN)##for random factors when log transformed
sm.density.compare(TRIAL_AFC_CLEAN$logAFC, TRIAL_AFC_CLEAN$GROUP)
legend("topright", levels(TRIAL_AFC_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_AFC_CLEAN$GROUP)))

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)
contrasts(TRIAL_AFC_CLEAN$condition_no) = matrix
contrasts(TRIAL_AFC_CLEAN$GROUP) <- contr.sdif(2)
lmerAFC = lmer(logAFC ~ GROUP*condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP*condition_no+CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TRIAL_AFC_CLEAN)                                                                                                            
qqnorm(resid(lmerAFC)) 
sm.density.compare(resid(lmerAFC), TRIAL_AFC_CLEAN$GROUP)
summary(lmerAFC)
plot(allEffects(lmerAFC))

#descriptives 
AFC.GROUP_MEAN =tapply(TRIAL_AFC_CLEAN$FIXATION_COUNT, list(TRIAL_AFC_CLEAN$GROUP, TRIAL_AFC_CLEAN$condition_no), mean, na.rm = TRUE)
AFC.GROUP_SD =tapply(TRIAL_AFC_CLEAN$FIXATION_COUNT, list(TRIAL_AFC_CLEAN$GROUP, TRIAL_AFC_CLEAN$condition_no), sd, na.rm = TRUE)

####################################Sentence Reading Time###################################

TRIAL_DUR = TRIAL_CLEAN
TRIAL_DUR <- TRIAL_DUR[!(is.na(TRIAL_DUR$DURATION)),] ##just in case there are any missing data points
str(TRIAL_DUR)

sm.density.compare(TRIAL_DUR$DURATION, TRIAL_DUR$GROUP)
legend("topright", levels(TRIAL_DUR$GROUP), fill=2+(0:nlevels(TRIAL_DUR$GROUP)))

####removing outliers >2.5sd from group/condition mean
mean.matrix.TRIAL_DUR = tapply(TRIAL_DUR$DURATION, list(TRIAL_DUR$GROUP,TRIAL_DUR$condition_no), mean, na.rm = TRUE)
mean.matrix.TRIAL_DUR
sd.matrix.TRIAL_DUR = tapply(TRIAL_DUR$DURATION, list(TRIAL_DUR$GROUP,TRIAL_DUR$condition_no), sd,na.rm = TRUE)
sd.matrix.TRIAL_DUR
nr = nrow(TRIAL_DUR)
for(i in 1:nr){TRIAL_DUR$mean.sc[i] = mean.matrix.TRIAL_DUR[TRIAL_DUR$GROUP[i],TRIAL_DUR$condition_no[i]]}
for(i in 1:nr){TRIAL_DUR$sd.sc[i] = sd.matrix.TRIAL_DUR[TRIAL_DUR$GROUP[i],TRIAL_DUR$condition_no[i]]}
for(i in 1:nr) {TRIAL_DUR$zscore[i] = (TRIAL_DUR$DURATION[i] - TRIAL_DUR$mean.sc[i])/TRIAL_DUR$sd.sc[i]}
#sink("TRIAL_DUR_OUTLIERS.txt")
#TRIAL_DUR[TRIAL_DUR$zscore > 2.5,]
#sink()
TRIAL_DUR_CLEAN = TRIAL_DUR[abs(TRIAL_DUR$zscore) < 2.5,]
TRIAL_DUR_CLEAN$zscore
##1469-1423 = (100/1469)*46 = 3.13% data lost
sm.density.compare(TRIAL_DUR_CLEAN$DURATION, TRIAL_DUR_CLEAN$GROUP)
legend("topright", levels(TRIAL_DUR_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_DUR_CLEAN$GROUP)))

#visualising and transforming data
qqnorm(TRIAL_DUR_CLEAN$DURATION)
qqmath(~DURATION|GROUP, data = TRIAL_DUR_CLEAN)
qqmath(~DURATION|RECORDING_SESSION_LABEL, data = TRIAL_DUR_CLEAN) ##for random factors
qqmath(~DURATION|stimulus_no, data = TRIAL_DUR_CLEAN) ##for random factors
TRIAL_DUR_CLEAN$logDURATION  = log(TRIAL_DUR_CLEAN$DURATION) ##log transform
qqmath(~logDURATION|GROUP, data = TRIAL_DUR_CLEAN)
sm.density.compare(TRIAL_DUR_CLEAN$logDURATION, TRIAL_DUR_CLEAN$GROUP)
legend("topright", levels(TRIAL_DUR_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_DUR_CLEAN$GROUP)))

#removing one very obvious outlier after logtransform
min(TRIAL_DUR_CLEAN$logDURATION)
TRIAL_DUR_CLEAN_outlier = TRIAL_DUR_CLEAN[TRIAL_DUR_CLEAN$logDURATION < 4.5,] ##identifying what datapoint this is
TRIAL_DUR_CLEAN = TRIAL_DUR_CLEAN[TRIAL_DUR_CLEAN$PPTRIAL != "td1712",] ##using unique identifier to remove data point
#in total now removed (100/1469)*47 = 3.20% of data
qqmath(~logDURATION|GROUP, data = TRIAL_DUR_CLEAN) #checking it has been deleted
sm.density.compare(TRIAL_DUR_CLEAN$logDURATION, TRIAL_DUR_CLEAN$GROUP)
legend("topright", levels(TRIAL_DUR_CLEAN$GROUP), fill=2+(0:nlevels(TRIAL_DUR_CLEAN$GROUP)))

####lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)
contrasts(TRIAL_DUR_CLEAN$condition_no) = matrix
contrasts(TRIAL_DUR_CLEAN$GROUP) <- contr.sdif(2)
lmerDUR = lmer(logDURATION ~ GROUP * condition_no + CENTRED_AGE+ (1+ condition_no|RECORDING_SESSION_LABEL) + (0 +GROUP+condition_no|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TRIAL_DUR_CLEAN)                                                                                                            
qqnorm(resid(lmerDUR)) ##checking distribution of residuals
sm.density(resid(lmerDUR))
sm.density.compare(resid(lmerDUR),TRIAL_DUR_CLEAN$GROUP)
summary(lmerDUR)
plot(allEffects(lmerDUR))

#descriptives
DUR.GROUP_MEAN =tapply(TRIAL_DUR_CLEAN$DURATION, list(TRIAL_DUR_CLEAN$GROUP, TRIAL_DUR_CLEAN$condition_no), mean, na.rm = TRUE)
DUR.GROUP_SD =tapply(TRIAL_DUR_CLEAN$DURATION, list(TRIAL_DUR_CLEAN$GROUP, TRIAL_DUR_CLEAN$condition_no), sd, na.rm = TRUE)

###################################################################################################
###############################INTEREST AREA EYE MOVEMENT ANALYSIS#################################
###################################################################################################

##Checking and correcting IA file structure 
str(IA)
IA$RECORDING_SESSION_LABEL = as.factor(IA$RECORDING_SESSION_LABEL)
IA$condition_no = as.factor(IA$condition_no)
IA$stimulus_no = as.factor(IA$stimulus_no)
IA$IA_ID = as.factor(IA$IA_ID)
IA$IA_SKIP = as.factor(IA$IA_SKIP)
IA$IA_REGRESSION_IN = as.factor(IA$IA_REGRESSION_IN)
IA$IA_REGRESSION_OUT = as.factor(IA$IA_REGRESSION_OUT)
IA$TRIAL_INDEX = as.factor(IA$TRIAL_INDEX)
IA$IA_FIRST_FIXATION_DURATION = as.numeric(IA$IA_FIRST_FIXATION_DURATION)
IA$IA_FIRST_RUN_DWELL_TIME = as.numeric(IA$IA_FIRST_RUN_DWELL_TIME)
IA$IA_REGRESSION_PATH_DURATION = as.numeric(IA$IA_REGRESSION_PATH_DURATION)
IA$IA_FIRST_RUN_FIXATION_COUNT = as.numeric(IA$IA_FIRST_RUN_FIXATION_COUNT)
IA$IA_DWELL_TIME = as.numeric(IA$IA_DWELL_TIME)
str(IA)
str(IA$condition_no)
str(IA$stimulus_no)

##Adding a column idenitifying participant group (ASD vs. TD)
IA$GROUP = IA$RECORDING_SESSION_LABEL 
IA$GROUP = revalue(IA$GROUP, c("ex1"="ASD", "ex2"="ASD", "ex3" = "ASD", "ex4" = "ASD", "ex5" = "ASD", "ex6" = "ASD","ex7" = "ASD", "ex8" = "ASD", "ex9" = "ASD", "ex10" = "ASD", "ex11" = "ASD", "ex12" = "ASD", "ex13" = "ASD", "ex14" = "ASD", "ex15" = "ASD", "ex16" = "ASD", "ex17" = "ASD", "ex18" = "ASD","ex19" = "ASD", "ex20" = "ASD", "ex21" = "ASD", "ex22" = "ASD", 
                               "td1" = "TD", "td2" = "TD", "td3" = "TD", "td4" = "TD", "td5" = "TD", "td6" = "TD", "td7" = "TD", "td8" = "TD", "td9" = "TD", "td10" = "TD", "td11" = "TD", "td12" = "TD", "td13" = "TD", "td14" = "TD", "td15" = "TD", "td16" = "TD", "td17" = "TD", "td18" = "TD", "td19" = "TD", "td20" = "TD", "td21" = "TD", "td22" = "TD", "td23" = "TD", "td24" = "TD"))
str(IA$GROUP)

#Removing fillers (F) and practice (P) trials 
IA = IA[IA$stimuli_filler == "S",]
IA = droplevels(IA)
unique(IA$stimuli_filler)

##Removing weird trials
IA$PPTRIAL=paste(IA$RECORDING_SESSION_LABEL, IA$TRIAL_INDEX, sep = "") #making variable that has unique values of participant id and trial number
head(IA)
#WEIRD$PPTRIAL = paste(WEIRD$RECORDING_SESSION_LABEL, WEIRD$TRIAL_INDEX, sep = "") #already done this when removing weird trials from trial report so do not need to repeat
#WEIRD$MARKS <- 1 #already done this when removing weird trials from trial report so do not need to repeat
IA_WEIRD_MARKED <- merge(WEIRD, IA, by = "PPTRIAL", all.y=TRUE)
head(IA_WEIRD_MARKED) #check that the merge worked
IA_PLAUS_WEIRD_DEL <- IA_WEIRD_MARKED[is.na(IA_WEIRD_MARKED$MARKS), ] #Delete the trials from the ia report that are marked with 1
(100/8285)*235 #2.83% of data removed (8285-8050) 
#47*5 (5 REGIONS PER TRIAL) = 235

#removing repeated columns and returning column names to original
head(IA_PLAUS_WEIRD_DEL)
IA_PLAUS_WEIRD_DEL <- IA_PLAUS_WEIRD_DEL[,-(2:4),drop=FALSE]
names(IA_PLAUS_WEIRD_DEL)[names(IA_PLAUS_WEIRD_DEL)=="RECORDING_SESSION_LABEL.y"] <- "RECORDING_SESSION_LABEL"
head(IA_PLAUS_WEIRD_DEL)

#####removing trials when ppts blinked in the target
pp_blinks <- FIX[FIX$stimuli_filler == "S" & FIX$CURRENT_FIX_INTEREST_AREA_INDEX== 3 & FIX$CURRENT_FIX_BLINK_AROUND!= "NONE",] ##creating a file that contains the instances when a participant blinked whilst fixating the target region
pp_blinks$CURRENT_FIX_INTEREST_AREA_INDEX ##checking it worked
pp_blinks$CURRENT_FIX_BLINK_AROUND ##checking it worked
pp_blinks$stimuli_filler ##checking it worked

##Removing trials when there was a blink 
pp_blinks$PPTRIAL = paste(pp_blinks$RECORDING_SESSION_LABEL, pp_blinks$TRIAL_INDEX, sep = "") 
pp_blinks$PPTRIAL
pp_blinks_list <- as.data.frame(pp_blinks$PPTRIAL) #dataframe including only this info
names(pp_blinks_list)[names(pp_blinks_list)=="pp_blinks$PPTRIAL"] <- "PPTRIAL"
pp_blinks_list$MARKS <- 1
pp_blinks_list = unique(pp_blinks_list) ##removing duplicates - 148
IA_BLINK_MARKED <- merge(pp_blinks_list, IA_PLAUS_WEIRD_DEL, by = "PPTRIAL", all.y=TRUE)
head(IA_BLINK_MARKED)
IA_CLEAN <- IA_BLINK_MARKED[is.na(IA_BLINK_MARKED$MARKS), ]
##8050-7335 = 100/8050*715 - 8.88% 

##Making a datafile for each seperate region
START<- IA_CLEAN[IA_CLEAN$IA_ID == 1,]
PRETARGET <- IA_CLEAN[IA_CLEAN$IA_ID == 2,]
TARGET <- IA_CLEAN[IA_CLEAN$IA_ID == 3,]
POSTTARGET <- IA_CLEAN[IA_CLEAN$IA_ID == 4,]
END <- IA_CLEAN[IA_CLEAN$IA_ID == 5,]

###################################################################################################
#########################################PRETARGET REGION##########################################

#########################################First Fixation Duration###################################
##removing empty cells and skips
PRETARGET_FFD = PRETARGET[PRETARGET$IA_SKIP == 0,]
PRETARGET_FFD <- PRETARGET_FFD[!(is.na(PRETARGET_FFD$IA_FIRST_FIXATION_DURATION)),] #in case any missing data
PRETARGET_FFD$IA_ID

#checking structure and distribution 
str(PRETARGET_FFD$condition_no)
str(PRETARGET_FFD$IA_FIRST_FIXATION_DURATION)
str(PRETARGET_FFD$stimulus_no)
qqnorm(PRETARGET_FFD$IA_FIRST_FIXATION_DURATION)
qqmath(~IA_FIRST_FIXATION_DURATION|GROUP, data = PRETARGET_FFD)
sm.density.compare(PRETARGET_FFD$IA_FIRST_FIXATION_DURATION, PRETARGET_FFD$GROUP)
legend("topright", levels(PRETARGET_FFD$GROUP), fill=2+(0:nlevels(PRETARGET_FFD$GROUP)))

##removing datapoints >2.5sd away from group and condition mean
mean.matrix.PRETARGET_FFD = tapply(PRETARGET_FFD$IA_FIRST_FIXATION_DURATION, list(PRETARGET_FFD$GROUP, PRETARGET_FFD$condition_no), mean, na.rm = TRUE)
mean.matrix.PRETARGET_FFD
sd.matrix.PRETARGET_FFD = tapply(PRETARGET_FFD$IA_FIRST_FIXATION_DURATION, list(PRETARGET_FFD$GROUP, PRETARGET_FFD$condition_no), sd, na.rm = TRUE)
sd.matrix.PRETARGET_FFD
nr=nrow(PRETARGET_FFD)
for(i in 1:nr){PRETARGET_FFD$mean.sc[i] = mean.matrix.PRETARGET_FFD[PRETARGET_FFD$GROUP[i],PRETARGET_FFD$condition_no[i]]}
for(i in 1:nr){PRETARGET_FFD$sd.sc[i] = sd.matrix.PRETARGET_FFD[PRETARGET_FFD$GROUP[i],PRETARGET_FFD$condition_no[i]]}
for(i in 1:nr) {PRETARGET_FFD$zscore[i] = (PRETARGET_FFD$IA_FIRST_FIXATION_DURATION[i] - PRETARGET_FFD$mean.sc[i])/PRETARGET_FFD$sd.sc[i]}
head(PRETARGET_FFD)
#sink("PRETARGET_FFD_OUTLIERS.txt") 
#PRETARGET_FFD[PRETARGET_FFD$zscore > 2.5,]
#sink()
PRETARGET_FFD_CLEAN = PRETARGET_FFD[abs(PRETARGET_FFD$zscore) < 2.5,]
head(PRETARGET_FFD_CLEAN)
#1366-1337 = 29 = 100/1365*29 = 2.12% data removed
sm.density.compare(PRETARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, PRETARGET_FFD_CLEAN$GROUP)
legend("topright", levels(PRETARGET_FFD_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_FFD_CLEAN$GROUP)))

##transform data for analysis and visualise (it doesn't need it, but as I mentioned earlier, I am transforming all data, given I have had to do it for some measures)
PRETARGET_FFD_CLEAN$logFFD  = log(PRETARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION)
qqmath(~logFFD|GROUP, data = PRETARGET_FFD_CLEAN)
qqmath(~logFFD, data = PRETARGET_FFD_CLEAN)
qqmath(~logFFD|RECORDING_SESSION_LABEL, data = PRETARGET_FFD_CLEAN)
qqmath(~logFFD|stimulus_no, data = PRETARGET_FFD_CLEAN)
sm.density.compare(PRETARGET_FFD_CLEAN$logFFD, PRETARGET_FFD_CLEAN$GROUP)
legend("topright", levels(PRETARGET_FFD_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_FFD_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)     
contrasts(PRETARGET_FFD_CLEAN$condition_no) = matrix
contrasts(PRETARGET_FFD_CLEAN$GROUP) <- contr.sdif(2)
lmerFFD_PRE = lmer(logFFD ~ GROUP*condition_no + CENTRED_AGE + (0 + condition_no|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = PRETARGET_FFD_CLEAN)                                                                                                            
qqnorm(resid(lmerFFD_PRE)) ##checking distribution of residuals
sm.density(resid(lmerFFD_PRE))
sm.density.compare(resid(lmerFFD_PRE), PRETARGET_FFD_CLEAN$GROUP)
summary(lmerFFD_PRE)
plot(allEffects(lmerFFD_PRE))

##descriptives
PRETARGET_FFD.GROUP_MEAN = tapply(PRETARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, list(PRETARGET_FFD_CLEAN$GROUP, PRETARGET_FFD_CLEAN$condition_no), mean)
PRETARGET_FFD.GROUP_SD = tapply(PRETARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, list(PRETARGET_FFD_CLEAN$GROUP, PRETARGET_FFD_CLEAN$condition_no), sd)

#########################################Gaze Duration###################################
##removing any empty cells and skips
PRETARGET_GD = PRETARGET[PRETARGET$IA_SKIP == 0,]
PRETARGET_GD <- PRETARGET_GD[!(is.na(PRETARGET_GD$IA_FIRST_RUN_DWELL_TIME)),] #in case there are any NA's

#checking structure and normality
str(PRETARGET_GD)
qqnorm(PRETARGET_GD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = PRETARGET_GD)
sm.density.compare(PRETARGET_GD$IA_FIRST_RUN_DWELL_TIME, PRETARGET_GD$GROUP)
legend("topright", levels(PRETARGET_GD$GROUP), fill=2+(0:nlevels(PRETARGET_GD$GROUP)))

##removing outliers >2.5sd from group/condition mean
mean.matrix.PRETARGET_GD = tapply(PRETARGET_GD$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_GD$GROUP, PRETARGET_GD$condition_no), mean, na.rm = TRUE)
mean.matrix.PRETARGET_GD
sd.matrix.PRETARGET_GD = tapply(PRETARGET_GD$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_GD$GROUP, PRETARGET_GD$condition_no), sd, na.rm = TRUE)
sd.matrix.PRETARGET_GD
nr=nrow(PRETARGET_GD)
for(i in 1:nr){PRETARGET_GD$mean.sc[i] = mean.matrix.PRETARGET_GD[PRETARGET_GD$GROUP[i],PRETARGET_GD$condition_no[i]]}
for(i in 1:nr){PRETARGET_GD$sd.sc[i] = sd.matrix.PRETARGET_GD[PRETARGET_GD$GROUP[i],PRETARGET_GD$condition_no[i]]}
for(i in 1:nr) {PRETARGET_GD$zscore[i] = (PRETARGET_GD$IA_FIRST_RUN_DWELL_TIME[i] - PRETARGET_GD$mean.sc[i])/PRETARGET_GD$sd.sc[i]}
head(PRETARGET_GD)
#sink("PRETARGET_GD_OUTLIERS.txt")
#PRETARGET_GD[PRETARGET_GD$zscore > 2.5,]
#sink()
PRETARGET_GD_CLEAN = PRETARGET_GD[abs(PRETARGET_GD$zscore) < 2.5,]
head(PRETARGET_GD_CLEAN)
#rechecking distributions
sm.density.compare(PRETARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, PRETARGET_GD_CLEAN$GROUP)
legend("topright", levels(PRETARGET_GD_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_GD_CLEAN$GROUP)))
##1366-1326 = 100/1365*40 = 2.93%

##descriptives
PRETARGET_GD.GROUP_MEAN = tapply(PRETARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_GD_CLEAN$GROUP, PRETARGET_GD_CLEAN$condition_no), mean)
PRETARGET_GD.GROUP_SD = tapply(PRETARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_GD_CLEAN$GROUP, PRETARGET_GD_CLEAN$condition_no), sd)

##transform data for analysis
PRETARGET_GD_CLEAN$logGD  = log(PRETARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logGD|GROUP, data = PRETARGET_GD_CLEAN)
qqmath(~logGD, data = PRETARGET_GD_CLEAN)
qqmath(~logGD|RECORDING_SESSION_LABEL, data = PRETARGET_GD_CLEAN)
qqmath(~logGD|stimulus_no, data = PRETARGET_GD_CLEAN)
sm.density.compare(PRETARGET_GD_CLEAN$logGD, PRETARGET_GD_CLEAN$GROUP)
legend("topright", levels(PRETARGET_GD_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_GD_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)     
contrasts(PRETARGET_GD_CLEAN$condition_no) = matrix
contrasts(PRETARGET_GD_CLEAN$GROUP) <- contr.sdif(2)
lmerGD_PRE = lmer(logGD ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = PRETARGET_GD_CLEAN)                                                                                                            
qqnorm(resid(lmerGD_PRE))
sm.density(resid(lmerGD_PRE))
sm.density.compare(resid(lmerGD_PRE),PRETARGET_GD_CLEAN$GROUP)
summary(lmerGD_PRE)
plot(allEffects(lmerGD_PRE))

#########################################Single Fixation Duration###################################
##removing empty cells and skips
PRETARGET_SFD = PRETARGET[PRETARGET$IA_SKIP == 0 & PRETARGET$IA_FIXATION_COUNT ==1,]
PRETARGET_SFD <- PRETARGET_SFD[!(is.na(PRETARGET_SFD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and normality
str(PRETARGET_SFD)
qqnorm(PRETARGET_SFD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = PRETARGET_SFD)
sm.density.compare(PRETARGET_SFD$IA_FIRST_RUN_DWELL_TIME, PRETARGET_SFD$GROUP)
legend("topright", levels(PRETARGET_SFD$GROUP), fill=2+(0:nlevels(PRETARGET_SFD$GROUP)))

##removing outliers >2.5sd from group/condition mean
mean.matrix.PRETARGET_SFD = tapply(PRETARGET_SFD$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_SFD$GROUP, PRETARGET_SFD$condition_no), mean, na.rm = TRUE)
mean.matrix.PRETARGET_SFD
sd.matrix.PRETARGET_SFD = tapply(PRETARGET_SFD$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_SFD$GROUP, PRETARGET_SFD$condition_no), sd, na.rm = TRUE)
sd.matrix.PRETARGET_SFD
nr=nrow(PRETARGET_SFD)
for(i in 1:nr){PRETARGET_SFD$mean.sc[i] = mean.matrix.PRETARGET_SFD[PRETARGET_SFD$GROUP[i],PRETARGET_SFD$condition_no[i]]}
for(i in 1:nr){PRETARGET_SFD$sd.sc[i] = sd.matrix.PRETARGET_SFD[PRETARGET_SFD$GROUP[i],PRETARGET_SFD$condition_no[i]]}
for(i in 1:nr) {PRETARGET_SFD$zscore[i] = (PRETARGET_SFD$IA_FIRST_RUN_DWELL_TIME[i] - PRETARGET_SFD$mean.sc[i])/PRETARGET_SFD$sd.sc[i]}
head(PRETARGET_SFD)
#sink("PRETARGET_SFD_OUTLIERS.txt")
#PRETARGET_SFD[PRETARGET_SFD$zscore > 2.5,]
#sink()
PRETARGET_SFD_CLEAN = PRETARGET_SFD[abs(PRETARGET_SFD$zscore) < 2.5,]
head(PRETARGET_SFD_CLEAN)
##417-409 = 100/417*8 = 1.92% lost
sm.density.compare(PRETARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, PRETARGET_SFD$GROUP)
legend("topright", levels(PRETARGET_SFD_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_SFD$GROUP)))

##descriptives
PRETARGET_SFD.GROUP_MEAN = tapply(PRETARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_SFD_CLEAN$GROUP, PRETARGET_SFD_CLEAN$condition_no), mean, na.rm = TRUE)
PRETARGET_SFD.GROUP_SD = tapply(PRETARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(PRETARGET_SFD_CLEAN$GROUP, PRETARGET_SFD_CLEAN$condition_no), sd, na.rm = TRUE)

##transform data for analysis and visualise 
PRETARGET_SFD_CLEAN$logSFD  = log(PRETARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logSFD|GROUP, data = PRETARGET_SFD_CLEAN)
qqmath(~logSFD, data = PRETARGET_SFD_CLEAN)
qqmath(~logSFD|RECORDING_SESSION_LABEL, data = PRETARGET_SFD_CLEAN)
qqmath(~logSFD|stimulus_no, data = PRETARGET_SFD_CLEAN)
sm.density.compare(PRETARGET_SFD_CLEAN$logSFD, PRETARGET_SFD_CLEAN$GROUP)
legend("topright", levels(PRETARGET_SFD_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_SFD$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)     
contrasts(PRETARGET_SFD_CLEAN$condition_no) = matrix
contrasts(PRETARGET_SFD_CLEAN$GROUP) <- contr.sdif(2)
lmerSFD_PRE = lmer(logSFD ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = PRETARGET_SFD_CLEAN)                                                                                                            
sm.density(resid(lmerSFD_PRE))
sm.density.compare(resid(lmerSFD_PRE), PRETARGET_SFD_CLEAN$GROUP)
qqnorm(resid(lmerSFD_PRE))
summary(lmerSFD_PRE)
plot(allEffects(lmerSFD_PRE))

#########################################Go Past Time###################################
##removing empty cells and skips
PRETARGET_GP = PRETARGET[PRETARGET$IA_SKIP == 0,]
PRETARGET_GP <- PRETARGET_GP[!(is.na(PRETARGET_GP$IA_REGRESSION_PATH_DURATION)),] #removing any NA's

#checking structure and distribution
str(PRETARGET_GP)
qqnorm(PRETARGET_GP$IA_REGRESSION_PATH_DURATION)
qqmath(~IA_REGRESSION_PATH_DURATION|GROUP, data = PRETARGET_GP)
sm.density.compare(PRETARGET_GP$IA_REGRESSION_PATH_DURATION, PRETARGET_GP$GROUP)
legend("topright", levels(PRETARGET_GP$GROUP), fill=2+(0:nlevels(PRETARGET_GP$GROUP)))

##removing outliers >2.5sd from group/condition mean
mean.matrix.PRETARGET_GP = tapply(PRETARGET_GP$IA_REGRESSION_PATH_DURATION, list(PRETARGET_GP$GROUP, PRETARGET_GP$condition_no), mean, na.rm = TRUE)
mean.matrix.PRETARGET_GP
sd.matrix.PRETARGET_GP = tapply(PRETARGET_GP$IA_REGRESSION_PATH_DURATION, list(PRETARGET_GP$GROUP, PRETARGET_GP$condition_no), sd, na.rm = TRUE)
sd.matrix.PRETARGET_GP
nr=nrow(PRETARGET_GP)
for(i in 1:nr){PRETARGET_GP$mean.sc[i] = mean.matrix.PRETARGET_GP[PRETARGET_GP$GROUP[i],PRETARGET_GP$condition_no[i]]}
for(i in 1:nr){PRETARGET_GP$sd.sc[i] = sd.matrix.PRETARGET_GP[PRETARGET_GP$GROUP[i],PRETARGET_GP$condition_no[i]]}
for(i in 1:nr) {PRETARGET_GP$zscore[i] = (PRETARGET_GP$IA_REGRESSION_PATH_DURATION[i] - PRETARGET_GP$mean.sc[i])/PRETARGET_GP$sd.sc[i]}
head(PRETARGET_GP)
#sink("PRETARGET_GP_OUTLIERS.txt")
#PRETARGET_GP[PRETARGET_GP$zscore > 2.5,]
#sink()
PRETARGET_GP_CLEAN = PRETARGET_GP[abs(PRETARGET_GP$zscore) < 2.5,]
head(PRETARGET_GP_CLEAN)
#1366-1329 - (100/1365)*37 = 2.71% of data deleted
sm.density.compare(PRETARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, PRETARGET_GP_CLEAN$GROUP)
legend("topright", levels(PRETARGET_GP_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_GP_CLEAN$GROUP)))

##descriptives
PRETARGET_GP.GROUP_MEAN = tapply(PRETARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, list(PRETARGET_GP_CLEAN$GROUP, PRETARGET_GP_CLEAN$condition_no), mean)
PRETARGET_GP.GROUP_SD = tapply(PRETARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, list(PRETARGET_GP_CLEAN$GROUP, PRETARGET_GP_CLEAN$condition_no), sd)

##transform data for analysis
PRETARGET_GP_CLEAN$logGP  = log(PRETARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION)
qqmath(~logGP|GROUP, data = PRETARGET_GP_CLEAN)
qqmath(~logGP, data = PRETARGET_GP_CLEAN)
qqmath(~logGP|RECORDING_SESSION_LABEL, data = PRETARGET_GP_CLEAN)
qqmath(~logGP|stimulus_no, data = PRETARGET_GP_CLEAN)
sm.density.compare(PRETARGET_GP_CLEAN$logGP, PRETARGET_GP_CLEAN$GROUP)
legend("topright", levels(PRETARGET_GP_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_GP_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)        
contrasts(PRETARGET_GP_CLEAN$condition_no) = matrix
contrasts(PRETARGET_GP_CLEAN$GROUP) <- contr.sdif(2)
lmerGP_PRE = lmer(logGP ~ GROUP*condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = PRETARGET_GP_CLEAN)                                                                                                            
sm.density(resid(lmerGP_PRE))
sm.density.compare(resid(lmerGP_PRE), PRETARGET_GP_CLEAN$GROUP)
qqnorm(resid(lmerGP_PRE))
summary(lmerGP_PRE)
plot(allEffects(lmerGP_PRE))

#########################################Total Time###################################
##removing empty cells and skips
PRETARGET_TT = PRETARGET[PRETARGET$IA_SKIP == 0,]
PRETARGET_TT <- PRETARGET_TT[!(is.na(PRETARGET_TT$IA_DWELL_TIME)),] #removing any NA's

#checking structure and normality
str(PRETARGET_TT)
qqnorm(PRETARGET_GP$IA_DWELL_TIME)
qqmath(~IA_DWELL_TIME|GROUP, data = PRETARGET_TT)
sm.density.compare(PRETARGET_TT$IA_DWELL_TIME, PRETARGET_TT$GROUP)
legend("topright", levels(PRETARGET_TT$GROUP), fill=2+(0:nlevels(PRETARGET_TT$GROUP)))

##removing outliers >2.5sd from group/condition mean
mean.matrix.PRETARGET_TT = tapply(PRETARGET_TT$IA_DWELL_TIME, list(PRETARGET_TT$GROUP, PRETARGET_TT$condition_no), mean, na.rm = TRUE)
mean.matrix.PRETARGET_TT
sd.matrix.PRETARGET_TT = tapply(PRETARGET_TT$IA_DWELL_TIME, list(PRETARGET_TT$GROUP, PRETARGET_TT$condition_no), sd, na.rm = TRUE)
sd.matrix.PRETARGET_TT
nr=nrow(PRETARGET_TT)
for(i in 1:nr){PRETARGET_TT$mean.sc[i] = mean.matrix.PRETARGET_TT[PRETARGET_TT$GROUP[i],PRETARGET_TT$condition_no[i]]}
for(i in 1:nr){PRETARGET_TT$sd.sc[i] = sd.matrix.PRETARGET_TT[PRETARGET_TT$GROUP[i],PRETARGET_TT$condition_no[i]]}
for(i in 1:nr) {PRETARGET_TT$zscore[i] = (PRETARGET_TT$IA_DWELL_TIME[i] - PRETARGET_TT$mean.sc[i])/PRETARGET_TT$sd.sc[i]}
head(PRETARGET_TT)
sink("PRETARGET_TT_OUTLIERS.txt")
PRETARGET_TT[PRETARGET_TT$zscore > 2.5,]
sink()
PRETARGET_TT_CLEAN = PRETARGET_TT[abs(PRETARGET_TT$zscore) < 2.5,]
head(PRETARGET_TT_CLEAN)
#1366-1319 = 47 = (100/1365)*47 = 3.44% of data lost
sm.density.compare(PRETARGET_TT_CLEAN$IA_DWELL_TIME, PRETARGET_TT_CLEAN$GROUP)
legend("topright", levels(PRETARGET_TT_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_TT_CLEAN$GROUP)))

##descriptives
PRETARGET_TT.GROUP_MEAN = tapply(PRETARGET_TT_CLEAN$IA_DWELL_TIME, list(PRETARGET_TT_CLEAN$GROUP, PRETARGET_TT_CLEAN$condition_no), mean)
PRETARGET_TT.GROUP_SD = tapply(PRETARGET_TT_CLEAN$IA_DWELL_TIME, list(PRETARGET_TT_CLEAN$GROUP, PRETARGET_TT_CLEAN$condition_no), sd)

##transform data for analysis
PRETARGET_TT_CLEAN$logTT  = log(PRETARGET_TT_CLEAN$IA_DWELL_TIME)
qqmath(~logTT|GROUP, data = PRETARGET_TT_CLEAN)
qqmath(~logTT, data = PRETARGET_TT_CLEAN)
qqmath(~logTT|RECORDING_SESSION_LABEL, data = PRETARGET_TT_CLEAN)
qqmath(~logTT|stimulus_no, data = PRETARGET_TT_CLEAN)
sm.density.compare(PRETARGET_TT_CLEAN$logTT, PRETARGET_TT_CLEAN$GROUP)
legend("topright", levels(PRETARGET_TT_CLEAN$GROUP), fill=2+(0:nlevels(PRETARGET_TT_CLEAN$GROUP)))

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)     
contrasts(PRETARGET_TT_CLEAN$condition_no) = matrix
contrasts(PRETARGET_TT_CLEAN$GROUP) <- contr.sdif(2)
lmerTT_PRE = lmer(logTT ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = PRETARGET_TT_CLEAN)                                                                                                            
sm.density(resid(lmerTT_PRE))
sm.density.compare(resid(lmerTT_PRE),PRETARGET_TT_CLEAN$GROUP)
qqnorm(resid(lmerTT_PRE))
summary(lmerTT_PRE)
plot(allEffects(lmerTT_PRE))

###################################################################################################
#########################################TARGET REGION##########################################

#######################################First fixation duration###################################

##removing empty cells and skips
TARGET_FFD = TARGET[TARGET$IA_SKIP == 0,]
TARGET_FFD <- TARGET_FFD[!(is.na(TARGET_FFD$IA_FIRST_FIXATION_DURATION)),]

#checking structure and distribution
str(TARGET_FFD)
qqnorm(TARGET_FFD$IA_FIRST_FIXATION_DURATION)
qqmath(~IA_FIRST_FIXATION_DURATION|GROUP, data = TARGET_FFD)
sm.density.compare(TARGET_FFD$IA_FIRST_FIXATION_DURATION, TARGET_FFD$GROUP)
legend("topright", levels(TARGET_FFD$GROUP), fill=2+(0:nlevels(TARGET_FFD$GROUP)))

##removing outliers >2.5sd from group/condition mean
mean.matrix.TARGET_FFD = tapply(TARGET_FFD$IA_FIRST_FIXATION_DURATION, list(TARGET_FFD$GROUP, TARGET_FFD$condition_no), mean, na.rm = TRUE)
mean.matrix.TARGET_FFD
sd.matrix.TARGET_FFD = tapply(TARGET_FFD$IA_FIRST_FIXATION_DURATION, list(TARGET_FFD$GROUP, TARGET_FFD$condition_no), sd, na.rm = TRUE)
sd.matrix.TARGET_FFD
nr=nrow(TARGET_FFD)
for(i in 1:nr){TARGET_FFD$mean.sc[i] = mean.matrix.TARGET_FFD[TARGET_FFD$GROUP[i],TARGET_FFD$condition_no[i]]}
for(i in 1:nr){TARGET_FFD$sd.sc[i] = sd.matrix.TARGET_FFD[TARGET_FFD$GROUP[i],TARGET_FFD$condition_no[i]]}
for(i in 1:nr) {TARGET_FFD$zscore[i] = (TARGET_FFD$IA_FIRST_FIXATION_DURATION[i] - TARGET_FFD$mean.sc[i])/TARGET_FFD$sd.sc[i]}
head(TARGET_FFD)
#sink("TARGET_FFD_OUTLIERS.txt")
#TARGET_FFD[TARGET_FFD$zscore > 2.5,]
#sink()
TARGET_FFD_CLEAN = TARGET_FFD[abs(TARGET_FFD$zscore) < 2.5,]
head(TARGET_FFD_CLEAN)
##1214-1181 = 33= 100/1214*33 = 2.72% of data removed 
sm.density.compare(TARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, TARGET_FFD_CLEAN$GROUP)
legend("topright", levels(TARGET_FFD_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_FFD_CLEAN$GROUP)))

##descriptives
TARGET_FFD.GROUP_MEAN = tapply(TARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, list(TARGET_FFD_CLEAN$GROUP, TARGET_FFD_CLEAN$condition_no), mean)
TARGET_FFD.GROUP_SD = tapply(TARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, list(TARGET_FFD_CLEAN$GROUP, TARGET_FFD_CLEAN$condition_no), sd)

##transform data for analysis
TARGET_FFD_CLEAN$logFFD  = log(TARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION)
qqmath(~logFFD|GROUP, data = TARGET_FFD_CLEAN)
qqmath(~logFFD, data = TARGET_FFD_CLEAN)
qqmath(~logFFD|RECORDING_SESSION_LABEL, data = TARGET_FFD_CLEAN)
qqmath(~logFFD|stimulus_no, data = TARGET_FFD_CLEAN)
TARGET_FFD_CLEAN$logFFD
sm.density.compare(TARGET_FFD_CLEAN$logFFD, TARGET_FFD_CLEAN$GROUP)
legend("topright", levels(TARGET_FFD_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_FFD_CLEAN$GROUP)))

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)   
contrasts(TARGET_FFD_CLEAN$condition_no) = matrix
contrasts(TARGET_FFD_CLEAN$GROUP) <- contr.sdif(2)
lmerFFD_TAR = lmer(logFFD ~ GROUP * condition_no + (1 + condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TARGET_FFD_CLEAN)                                                                                                            
sm.density(resid(lmerFFD_TAR))
sm.density.compare(resid(lmerFFD_TAR), TARGET_FFD_CLEAN$GROUP)
qqnorm(resid(lmerFFD_TAR))
summary(lmerFFD_TAR)
plot(allEffects(lmerFFD_TAR))

##Below I analyse the data seperately for each group to examine the interaction 
TARGET_FFD_CLEAN_TD_ONLY = TARGET_FFD_CLEAN[TARGET_FFD_CLEAN$GROUP == "TD",]
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)   
contrasts(TARGET_FFD_CLEAN_TD_ONLY$condition_no) = matrix
lmerFFD_TAR_TD = lmer(logFFD ~ condition_no + CENTRED_AGE +(1 + condition_no|RECORDING_SESSION_LABEL) + (1+condition_no+CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TARGET_FFD_CLEAN_TD_ONLY)                                                                                                            
summary(lmerFFD_TAR_TD) 


TARGET_FFD_CLEAN_ASD_ONLY = TARGET_FFD_CLEAN[TARGET_FFD_CLEAN$GROUP == "ASD",]
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)   
contrasts(TARGET_FFD_CLEAN_ASD_ONLY$condition_no) = matrix
lmerFFD_TAR_ASD = lmer(logFFD ~ condition_no +CENTRED_AGE +(1 + condition_no|RECORDING_SESSION_LABEL) + (1+condition_no|stimulus_no), control=lmerControl(optCtrl=list(maxfun=600000)), data = TARGET_FFD_CLEAN_ASD_ONLY)                                                                                                            
summary(lmerFFD_TAR_ASD) 

#######################################Gaze duration###################################
##removing any empty cells and skips
TARGET_GD = TARGET[TARGET$IA_SKIP == 0,]
TARGET_GD <- TARGET_GD[!(is.na(TARGET_GD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and normality
str(TARGET_GD)
qqnorm(TARGET_GD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = TARGET_GD)
sm.density.compare(TARGET_GD$IA_FIRST_RUN_DWELL_TIME, TARGET_GD$GROUP)
legend("topright", levels(TARGET_GD$GROUP), fill=2+(0:nlevels(TARGET_GD$GROUP)))

#removing outliers >2.5sd from group/condition mean
mean.matrix.TARGET_GD = tapply(TARGET_GD$IA_FIRST_RUN_DWELL_TIME, list(TARGET_GD$GROUP, TARGET_GD$condition_no), mean, na.rm = TRUE)
mean.matrix.TARGET_GD
sd.matrix.TARGET_GD = tapply(TARGET_GD$IA_FIRST_RUN_DWELL_TIME, list(TARGET_GD$GROUP, TARGET_GD$condition_no), sd, na.rm = TRUE)
sd.matrix.TARGET_GD
nr=nrow(TARGET_GD)
for(i in 1:nr){TARGET_GD$mean.sc[i] = mean.matrix.TARGET_GD[TARGET_GD$GROUP[i],TARGET_GD$condition_no[i]]}
for(i in 1:nr){TARGET_GD$sd.sc[i] = sd.matrix.TARGET_GD[TARGET_GD$GROUP[i],TARGET_GD$condition_no[i]]}
for(i in 1:nr) {TARGET_GD$zscore[i] = (TARGET_GD$IA_FIRST_RUN_DWELL_TIME[i] - TARGET_GD$mean.sc[i])/TARGET_GD$sd.sc[i]}
head(TARGET_GD)
#sink("TARGET_GD_OUTLIERS.txt")
#TARGET_GD[TARGET_GD$zscore > 2.5,]
#sink()
TARGET_GD_CLEAN = TARGET_GD[abs(TARGET_GD$zscore) < 2.5,]
head(TARGET_GD_CLEAN)
#1214-1183 = 31 = 100/1214*31 = 2.55% lost
sm.density.compare(TARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, TARGET_GD_CLEAN$GROUP)
legend("topright", levels(TARGET_GD_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_GD_CLEAN$GROUP)))

##descriptives
TARGET_GD.GROUP_MEAN = tapply(TARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(TARGET_GD_CLEAN$GROUP, TARGET_GD_CLEAN$condition_no), mean)
TARGET_GD.GROUP_SD = tapply(TARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(TARGET_GD_CLEAN$GROUP, TARGET_GD_CLEAN$condition_no), sd)

##transform data for analysis
TARGET_GD_CLEAN$logGD  = log(TARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logGD|GROUP, data = TARGET_GD_CLEAN)
qqmath(~logGD, data = TARGET_GD_CLEAN)
qqmath(~logGD|RECORDING_SESSION_LABEL, data = TARGET_GD_CLEAN)
qqmath(~logGD|stimulus_no, data = TARGET_GD_CLEAN)
sm.density.compare(TARGET_GD_CLEAN$logGD, TARGET_GD_CLEAN$GROUP)
legend("topright", levels(TARGET_GD_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_GD_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)    
contrasts(TARGET_GD_CLEAN$condition_no) = matrix
contrasts(TARGET_GD_CLEAN$GROUP) <- contr.sdif(2)
lmerGD_TAR = lmer(logGD ~ GROUP*condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no+CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TARGET_GD_CLEAN)                                                                                                            
sm.density(resid(lmerGD_TAR))
sm.density.compare(resid(lmerGD_TAR), TARGET_GD_CLEAN$GROUP)
qqnorm(resid(lmerGD_TAR))
summary(lmerGD_TAR)
plot(allEffects(lmerGD_TAR))

#######################################Single fixation duration###################################
TARGET_SFD = TARGET[TARGET$IA_SKIP == 0 & TARGET$IA_FIXATION_COUNT == 1,]
TARGET_SFD <- TARGET_SFD[!(is.na(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and distibution
str(TARGET_SFD)
qqnorm(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = TARGET_SFD)
sm.density.compare(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME, TARGET_SFD$GROUP)
legend("topright", levels(TARGET_SFD$GROUP), fill=2+(0:nlevels(TARGET_SFD$GROUP)))
min(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME)
max(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME)

#removing outliers >2.5sd from group/condition mean
mean.matrix.TARGET_SFD = tapply(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME, list(TARGET_SFD$GROUP, TARGET_SFD$condition_no), mean, na.rm = TRUE)
mean.matrix.PRETARGET_SFD
sd.matrix.TARGET_SFD = tapply(TARGET_SFD$IA_FIRST_RUN_DWELL_TIME, list(TARGET_SFD$GROUP, TARGET_SFD$condition_no), sd, na.rm = TRUE)
sd.matrix.TARGET_SFD
nr=nrow(TARGET_SFD)
for(i in 1:nr){TARGET_SFD$mean.sc[i] = mean.matrix.TARGET_SFD[TARGET_SFD$GROUP[i],TARGET_SFD$condition_no[i]]}
for(i in 1:nr){TARGET_SFD$sd.sc[i] = sd.matrix.TARGET_SFD[TARGET_SFD$GROUP[i],TARGET_SFD$condition_no[i]]}
for(i in 1:nr) {TARGET_SFD$zscore[i] = (TARGET_SFD$IA_FIRST_RUN_DWELL_TIME[i] - TARGET_SFD$mean.sc[i])/TARGET_SFD$sd.sc[i]}
head(TARGET_SFD)
#sink("TARGET_SFD_OUTLIERS.txt")
#TARGET_SFD[TARGET_SFD$zscore > 2.5,]
#sink()
TARGET_SFD_CLEAN = TARGET_SFD[abs(TARGET_SFD$zscore) < 2.5,]
head(TARGET_SFD_CLEAN)
##645-629 = 16= (100/645)*16 = 2.48% of data removed
sm.density.compare(TARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, TARGET_SFD_CLEAN$GROUP)
legend("topright", levels(TARGET_SFD_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_SFD_CLEAN$GROUP)))

##descriptives
TARGET_SFD.GROUP_MEAN = tapply(TARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(TARGET_SFD_CLEAN$GROUP, TARGET_SFD_CLEAN$condition_no), mean)
TARGET_SFD.GROUP_SD = tapply(TARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(TARGET_SFD_CLEAN$GROUP, TARGET_SFD_CLEAN$condition_no), sd)

##transform data for analysis
TARGET_SFD_CLEAN$logSFD  = log(TARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logSFD|GROUP, data = TARGET_SFD_CLEAN)
qqmath(~logSFD, data = TARGET_SFD_CLEAN)
qqmath(~logSFD|RECORDING_SESSION_LABEL, data = TARGET_SFD_CLEAN)
qqmath(~logSFD|stimulus_no, data = TARGET_SFD_CLEAN)
sm.density.compare(TARGET_SFD_CLEAN$logSFD, TARGET_SFD_CLEAN$GROUP)
legend("topright", levels(TARGET_SFD_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_SFD_CLEAN$GROUP)))

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)   
contrasts(TARGET_SFD_CLEAN$condition_no) = matrix
contrasts(TARGET_SFD_CLEAN$GROUP) <- contr.sdif(2)
lmerSFD_TAR = lmer(logSFD ~ GROUP *condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TARGET_SFD_CLEAN)                                                                                                            
sm.density(resid(lmerSFD_TAR))
sm.density.compare(resid(lmerSFD_TAR), TARGET_SFD_CLEAN$GROUP)
qqnorm(resid(lmerSFD_TAR))
summary(lmerSFD_TAR)
plot(allEffects(lmerSFD_TAR))

##Below the model is rerun seperately for each group to examine the interaction
TARGET_SFD_CLEAN_ASD_ONLY = TARGET_SFD_CLEAN[TARGET_SFD_CLEAN$GROUP == "ASD",]
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)   
contrasts(TARGET_SFD_CLEAN_ASD_ONLY$condition_no) = matrix
lmerTARGET_SFD_ASD = lmer(logSFD ~ condition_no + CENTRED_AGE +(1+ condition_no|RECORDING_SESSION_LABEL) + (1+ condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)),data = TARGET_SFD_CLEAN_ASD_ONLY)
summary(lmerTARGET_SFD_ASD)
summary(allEffects(lmerTARGET_SFD_ASD))
plot(allEffects(lmerTARGET_SFD_ASD))

TARGET_SFD_CLEAN_TD_ONLY = TARGET_SFD_CLEAN[TARGET_SFD_CLEAN$GROUP == "TD",]
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)   
contrasts(TARGET_SFD_CLEAN_TD_ONLY$condition_no) = matrix
lmerTARGET_SFD_CLEAN_TD = lmer(logSFD ~ condition_no + CENTRED_AGE+(1 + condition_no|RECORDING_SESSION_LABEL) + (1+ condition_no+CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)),data = TARGET_SFD_CLEAN_TD_ONLY)
summary(lmerTARGET_SFD_CLEAN_TD)
summary(allEffects(lmerTARGET_SFD_CLEAN_TD))
plot(allEffects(lmerTARGET_SFD_CLEAN_TD))

#########################################Go Past Time###################################

TARGET_GP = TARGET[TARGET$IA_SKIP == 0,]
TARGET_GP <- TARGET_GP[!(is.na(TARGET_GP$IA_REGRESSION_PATH_DURATION)),] #removing any NA's

#checking structure and normality
str(TARGET_GP)
qqnorm(TARGET_GP$IA_REGRESSION_PATH_DURATION)
qqmath(~IA_REGRESSION_PATH_DURATION|GROUP, data = TARGET_GP)
sm.density.compare(TARGET_GP$IA_REGRESSION_PATH_DURATION, TARGET_GP$GROUP)
legend("topright", levels(TARGET_GP$GROUP), fill=2+(0:nlevels(TARGET_GP$GROUP)))

##removing outliers >2.5sd above the group/condition mean
mean.matrix.TARGET_GP = tapply(TARGET_GP$IA_REGRESSION_PATH_DURATION, list(TARGET_GP$GROUP, TARGET_GP$condition_no), mean, na.rm = TRUE)
mean.matrix.TARGET_GP
sd.matrix.TARGET_GP = tapply(TARGET_GP$IA_REGRESSION_PATH_DURATION, list(TARGET_GP$GROUP, TARGET_GP$condition_no), sd, na.rm = TRUE)
sd.matrix.TARGET_GP
nr=nrow(TARGET_GP)
for(i in 1:nr){TARGET_GP$mean.sc[i] = mean.matrix.TARGET_GP[TARGET_GP$GROUP[i],TARGET_GP$condition_no[i]]}
for(i in 1:nr){TARGET_GP$sd.sc[i] = sd.matrix.TARGET_GP[TARGET_GP$GROUP[i],TARGET_GP$condition_no[i]]}
for(i in 1:nr) {TARGET_GP$zscore[i] = (TARGET_GP$IA_REGRESSION_PATH_DURATION[i] - TARGET_GP$mean.sc[i])/TARGET_GP$sd.sc[i]}
head(TARGET_GP)
#sink("TARGET_GP_OUTLIERS.txt")
#TARGET_GP[TARGET_GP$zscore > 2.5,]
#sink()
TARGET_GP_CLEAN = TARGET_GP[abs(TARGET_GP$zscore) < 2.5,]
head(TARGET_GP_CLEAN)
#1214-1177 = 37 = (100/1214)*37 = 3.04% of data lost
sm.density.compare(TARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, TARGET_GP_CLEAN$GROUP)
legend("topright", levels(TARGET_GP_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_GP_CLEAN$GROUP)))

##descriptives
TARGET_GP.GROUP_MEAN = tapply(TARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, list(TARGET_GP_CLEAN$GROUP, TARGET_GP_CLEAN$condition_no), mean)
TARGET_GP.GROUP_SD = tapply(TARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, list(TARGET_GP_CLEAN$GROUP, TARGET_GP_CLEAN$condition_no), sd)

##transform data for analysis
TARGET_GP_CLEAN$logGP  = log(TARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION)
qqmath(~logGP|GROUP, data = TARGET_GP_CLEAN)
qqmath(~logGP, data = TARGET_GP_CLEAN)
qqmath(~logGP|RECORDING_SESSION_LABEL, data = TARGET_GP_CLEAN)
qqmath(~logGP|stimulus_no, data = TARGET_GP_CLEAN)
sm.density.compare(TARGET_GP_CLEAN$logGP, TARGET_GP_CLEAN$GROUP)
legend("topright", levels(TARGET_GP_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_GP_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(TARGET_GP_CLEAN$condition_no) = matrix
contrasts(TARGET_GP_CLEAN$GROUP) <- contr.sdif(2)
lmerGP_TAR = lmer(logGP ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP*condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=500000)), data = TARGET_GP_CLEAN)                                                                                                            
sm.density(resid(lmerGP_TAR))
sm.density.compare(resid(lmerGP_TAR), TARGET_GP_CLEAN$GROUP)
qqnorm(resid(lmerGP_TAR))
summary(lmerGP_TAR)
plot(allEffects(lmerGP1_TAR))

#########################################Total Time###################################

TARGET_TT = TARGET[TARGET$IA_SKIP == 0,]
TARGET_TT <- TARGET_TT[!(is.na(TARGET_TT$IA_DWELL_TIME)),] #removing any NA's

#checking structure and distribution
str(TARGET_TT)
qqnorm(TARGET_GP$IA_DWELL_TIME)
qqmath(~IA_DWELL_TIME|GROUP, data = TARGET_TT)
sm.density.compare(TARGET_TT$IA_DWELL_TIME, TARGET_TT$GROUP)
legend("topright", levels(TARGET_TT$GROUP), fill=2+(0:nlevels(TARGET_TT$GROUP)))

#removing outliers >2.5sd from group/condition mean 
mean.matrix.TARGET_TT = tapply(TARGET_TT$IA_DWELL_TIME, list(TARGET_TT$GROUP, TARGET_TT$condition_no), mean, na.rm = TRUE)
mean.matrix.TARGET_TT
sd.matrix.TARGET_TT = tapply(TARGET_TT$IA_DWELL_TIME, list(TARGET_TT$GROUP, TARGET_TT$condition_no), sd, na.rm = TRUE)
sd.matrix.TARGET_TT
nr=nrow(TARGET_TT)
for(i in 1:nr){TARGET_TT$mean.sc[i] = mean.matrix.TARGET_TT[TARGET_TT$GROUP[i],TARGET_TT$condition_no[i]]}
for(i in 1:nr){TARGET_TT$sd.sc[i] = sd.matrix.TARGET_TT[TARGET_TT$GROUP[i],TARGET_TT$condition_no[i]]}
for(i in 1:nr) {TARGET_TT$zscore[i] = (TARGET_TT$IA_DWELL_TIME[i] - TARGET_TT$mean.sc[i])/TARGET_TT$sd.sc[i]}
head(TARGET_TT)
#sink("TARGET_TT_OUTLIERS.txt")
#TARGET_TT[TARGET_TT$zscore > 2.5,]
#sink()
TARGET_TT_CLEAN = TARGET_TT[abs(TARGET_TT$zscore) < 2.5,]
head(TARGET_TT_CLEAN)
#1214-1179 = 39 = 100/1214*35 = 2.88% removed
sm.density.compare(TARGET_TT_CLEAN$IA_DWELL_TIME, TARGET_TT_CLEAN$GROUP)
legend("topright", levels(TARGET_TT_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_TT_CLEAN$GROUP)))
max(TARGET_TT_CLEAN$IA_DWELL_TIME)

##descriptives
TARGET_TT.GROUP_MEAN = tapply(TARGET_TT_CLEAN$IA_DWELL_TIME, list(TARGET_TT_CLEAN$GROUP, TARGET_TT_CLEAN$condition_no), mean)
TARGET_TT.GROUP_SD = tapply(TARGET_TT_CLEAN$IA_DWELL_TIME, list(TARGET_TT_CLEAN$GROUP, TARGET_TT_CLEAN$condition_no), sd)

##transform data for analysis
TARGET_TT_CLEAN$logTT  = log(TARGET_TT_CLEAN$IA_DWELL_TIME)
qqmath(~logTT|GROUP, data = TARGET_TT_CLEAN)
qqmath(~logTT, data = TARGET_TT_CLEAN)
qqmath(~logTT|RECORDING_SESSION_LABEL, data = TARGET_TT_CLEAN)
qqmath(~logTT|stimulus_no, data = TARGET_TT_CLEAN)
sm.density.compare(TARGET_TT_CLEAN$logTT, TARGET_TT_CLEAN$GROUP)
legend("topright", levels(TARGET_TT_CLEAN$GROUP), fill=2+(0:nlevels(TARGET_TT_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(TARGET_TT_CLEAN$condition_no) = matrix
contrasts(TARGET_TT_CLEAN$GROUP) <- contr.sdif(2)
lmerTT_TAR = lmer(logTT ~ GROUP*condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)), data = TARGET_TT_CLEAN)                                                                                                            
sm.density(resid(lmerTT_TAR))
sm.density.compare(resid(lmerTT_TAR), TARGET_TT_CLEAN$GROUP)
qqnorm(resid(lmerTT_TAR))
summary(lmerTT_TAR)
plot(allEffects(lmerTT1_TAR))

#######################################POST TARGET REGION###################################
#######################################First fixation duration###################################
##removing empty cells and skips
POSTTARGET_FFD = POSTTARGET[POSTTARGET$IA_SKIP == 0,]
POSTTARGET_FFD <- POSTTARGET_FFD[!(is.na(POSTTARGET_FFD$IA_FIRST_FIXATION_DURATION)),]

#checking structure and distribution
str(POSTTARGET_FFD)
str(POSTTARGET_FFD$condition_no)
qqnorm(POSTTARGET_FFD$IA_FIRST_FIXATION_DURATION)
qqmath(~IA_FIRST_FIXATION_DURATION|GROUP, data = POSTTARGET_FFD)
sm.density.compare(POSTTARGET_FFD$IA_FIRST_FIXATION_DURATION, POSTTARGET_FFD$GROUP)
legend("topright", levels(POSTTARGET_FFD$GROUP), fill=2+(0:nlevels(POSTTARGET_FFD$GROUP)))

##removing outliers >2.5sd above group/condition mean
mean.matrix.POSTTARGET_FFD = tapply(POSTTARGET_FFD$IA_FIRST_FIXATION_DURATION, list(POSTTARGET_FFD$GROUP, POSTTARGET_FFD$condition_no), mean, na.rm = TRUE)
mean.matrix.POSTTARGET_FFD
sd.matrix.POSTTARGET_FFD = tapply(POSTTARGET_FFD$IA_FIRST_FIXATION_DURATION, list(POSTTARGET_FFD$GROUP, POSTTARGET_FFD$condition_no), sd, na.rm = TRUE)
sd.matrix.POSTTARGET_FFD
nr = nrow(POSTTARGET_FFD)
for(i in 1:nr){POSTTARGET_FFD$mean.sc[i] = mean.matrix.POSTTARGET_FFD[POSTTARGET_FFD$GROUP[i],POSTTARGET_FFD$condition_no[i]]}
for(i in 1:nr){POSTTARGET_FFD$sd.sc[i] = sd.matrix.POSTTARGET_FFD[POSTTARGET_FFD$GROUP[i],POSTTARGET_FFD$condition_no[i]]}
for(i in 1:nr) {POSTTARGET_FFD$zscore[i] = (POSTTARGET_FFD$IA_FIRST_FIXATION_DURATION[i] - POSTTARGET_FFD$mean.sc[i])/POSTTARGET_FFD$sd.sc[i]}
head(TARGET_FFD)
#sink("POSTTARGET_FFD_OUTLIERS.txt")
#POSTTARGET_FFD[POSTTARGET_FFD$zscore > 2.5,]
#sink()
POSTTARGET_FFD_CLEAN = POSTTARGET_FFD[abs(POSTTARGET_FFD$zscore) < 2.5,]
head(POSTTARGET_FFD_CLEAN)
##1188-1157 = 31 = (100/1187)*31 = 2.61% of FFD data
sm.density.compare(POSTTARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, POSTTARGET_FFD_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_FFD_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_FFD_CLEAN$GROUP)))

#rechecking distributions
qqnorm(POSTTARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION)
qqmath(~IA_FIRST_FIXATION_DURATION|GROUP, data = POSTTARGET_FFD_CLEAN)

#descriptives
POSTTARGET_FFD.GROUP_MEAN = tapply(POSTTARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, list(POSTTARGET_FFD_CLEAN$GROUP, POSTTARGET_FFD_CLEAN$condition_no), mean)
POSTTARGET_FFD.GROUP_SD = tapply(POSTTARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION, list(POSTTARGET_FFD_CLEAN$GROUP, POSTTARGET_FFD_CLEAN$condition_no), sd)

##transform data for analysis
POSTTARGET_FFD_CLEAN$logFFD  = log(POSTTARGET_FFD_CLEAN$IA_FIRST_FIXATION_DURATION)
qqmath(~logFFD|GROUP, data = POSTTARGET_FFD_CLEAN)
qqmath(~logFFD, data = POSTTARGET_FFD_CLEAN)
qqmath(~logFFD|RECORDING_SESSION_LABEL, data = POSTTARGET_FFD_CLEAN)
qqmath(~logFFD|stimulus_no, data = POSTTARGET_FFD_CLEAN)
sm.density.compare(POSTTARGET_FFD_CLEAN$logFFD, POSTTARGET_FFD_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_FFD_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_FFD_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_FFD_CLEAN$condition_no) = matrix
contrasts(POSTTARGET_FFD_CLEAN$GROUP) <- contr.sdif(2)
lmerFFD_POST = lmer(logFFD ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP*condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)), data =POSTTARGET_FFD_CLEAN)                                                                                                            
qqnorm(resid(lmerFFD_POST))
sm.density(resid(lmerFFD_POST))
sm.density.compare(resid(lmerFFD_POST), POSTTARGET_FFD_CLEAN$GROUP)
summary(lmerFFD_POST) 
plot(allEffects(lmerFFD_POST))
#######################################Single fixation duration###################################

##removing empty cells and skips
POSTTARGET_SFD = POSTTARGET[POSTTARGET$IA_SKIP == 0 &POSTTARGET$IA_FIXATION_COUNT ==1, ]
POSTTARGET_SFD <- POSTTARGET_SFD[!(is.na(POSTTARGET_SFD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and normality
str(POSTTARGET_SFD)
qqnorm(POSTTARGET_SFD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = POSTTARGET_SFD)
sm.density.compare(POSTTARGET_SFD$IA_FIRST_RUN_DWELL_TIME, POSTTARGET_SFD$GROUP)
legend("topright", levels(POSTTARGET_SFD$GROUP), fill=2+(0:nlevels(POSTTARGET_SFD$GROUP)))

#removing data points >2.5sd from group/condition mean
mean.matrix.POSTTARGET_SFD = tapply(POSTTARGET_SFD$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_SFD$GROUP, POSTTARGET_SFD$condition_no), mean, na.rm = TRUE)
mean.matrix.POSTTARGET_SFD
sd.matrix.POSTTARGET_SFD = tapply(POSTTARGET_SFD$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_SFD$GROUP, POSTTARGET_SFD$condition_no), sd, na.rm = TRUE)
sd.matrix.POSTTARGET_SFD
nr=nrow(POSTTARGET_SFD)
for(i in 1:nr){POSTTARGET_SFD$mean.sc[i] = mean.matrix.POSTTARGET_SFD[POSTTARGET_SFD$GROUP[i],POSTTARGET_SFD$condition_no[i]]}
for(i in 1:nr){POSTTARGET_SFD$sd.sc[i] = sd.matrix.POSTTARGET_SFD[POSTTARGET_SFD$GROUP[i],POSTTARGET_SFD$condition_no[i]]}
for(i in 1:nr) {POSTTARGET_SFD$zscore[i] = (POSTTARGET_SFD$IA_FIRST_RUN_DWELL_TIME[i] - POSTTARGET_SFD$mean.sc[i])/POSTTARGET_SFD$sd.sc[i]}
head(POSTTARGET_SFD)
#sink("POSTTARGET_SFD_OUTLIERS.txt")
#POSTTARGET_SFD[POSTTARGET_SFD$zscore > 2.5,]
#sink()
POSTTARGET_SFD_CLEAN = POSTTARGET_SFD[abs(POSTTARGET_SFD$zscore) < 2.5,]
str(POSTTARGET_SFD$zscore)
head(POSTTARGET_SFD_CLEAN)
##450-438 = 12 = (100/449)*12 = .2.67% data removed
sm.density.compare(POSTTARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, POSTTARGET_SFD_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_SFD_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_SFD_CLEAN$GROUP)))

##descriptives
POSTTARGET_SFD.GROUP_MEAN = tapply(POSTTARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_SFD_CLEAN$GROUP, POSTTARGET_SFD_CLEAN$condition_no), mean)
POSTTARGET_SFD.GROUP_SD = tapply(POSTTARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_SFD_CLEAN$GROUP, POSTTARGET_SFD_CLEAN$condition_no), sd)

##transform data for analysis
POSTTARGET_SFD_CLEAN$logSFD  = log(POSTTARGET_SFD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logSFD|GROUP, data = POSTTARGET_SFD_CLEAN)
qqmath(~logSFD, data = POSTTARGET_SFD_CLEAN)
qqmath(~logSFD|RECORDING_SESSION_LABEL, data = POSTTARGET_SFD_CLEAN)
qqmath(~logSFD|stimulus_no, data = POSTTARGET_SFD_CLEAN)
sm.density.compare(POSTTARGET_SFD_CLEAN$logSFD, POSTTARGET_SFD_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_SFD_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_SFD_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_SFD_CLEAN$condition_no) = matrix
contrasts(POSTTARGET_SFD_CLEAN$GROUP) <- contr.sdif(2)
lmerSFD_POST = lmer(logSFD ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP*condition_no +CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)), data =POSTTARGET_SFD_CLEAN)                                                                                                            
qqnorm(resid(lmerSFD_POST))
sm.density(resid(lmerSFD_POST))
sm.density.compare(resid(lmerSFD_POST), POSTTARGET_SFD_CLEAN$GROUP)
summary(lmerSFD_POST)
plot(allEffects(lmerSFD_POST))

#######################################Gaze duration###################################

POSTTARGET_GD = POSTTARGET[POSTTARGET$IA_SKIP == 0,]
POSTTARGET_GD <- POSTTARGET_GD[!(is.na(POSTTARGET_GD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and distribution
str(POSTTARGET_GD)
qqnorm(POSTTARGET_GD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = POSTTARGET_GD)
sm.density.compare(POSTTARGET_GD$IA_FIRST_RUN_DWELL_TIME, POSTTARGET_GD$GROUP)
legend("topright", levels(POSTTARGET_GD$GROUP), fill=2+(0:nlevels(POSTTARGET_GD$GROUP)))

#removing outliers >2.5sd group/condition mean
mean.matrix.POSTTARGET_GD = tapply(POSTTARGET_GD$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_GD$GROUP, POSTTARGET_GD$condition_no), mean, na.rm = TRUE)
mean.matrix.POSTTARGET_GD
sd.matrix.POSTTARGET_GD = tapply(POSTTARGET_GD$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_GD$GROUP, POSTTARGET_GD$condition_no), sd, na.rm = TRUE)
sd.matrix.POSTTARGET_GD
nr=nrow(POSTTARGET_GD)
for(i in 1:nr){POSTTARGET_GD$mean.sc[i] = mean.matrix.POSTTARGET_GD[POSTTARGET_GD$GROUP[i],POSTTARGET_GD$condition_no[i]]}
for(i in 1:nr){POSTTARGET_GD$sd.sc[i] = sd.matrix.POSTTARGET_GD[POSTTARGET_GD$GROUP[i],POSTTARGET_GD$condition_no[i]]}
for(i in 1:nr) {POSTTARGET_GD$zscore[i] = (POSTTARGET_GD$IA_FIRST_RUN_DWELL_TIME[i] - POSTTARGET_GD$mean.sc[i])/POSTTARGET_GD$sd.sc[i]}
head(POSTTARGET_GD)
#sink("POSTTARGET_GD_OUTLIERS.txt")
#POSTTARGET_GD[POSTTARGET_GD$zscore > 2.5,]
#sink()
POSTTARGET_GD_CLEAN = POSTTARGET_GD[abs(POSTTARGET_GD$zscore) < 2.5,]
head(POSTTARGET_GD_CLEAN)
##1188-1158 = 35 = 100/1187*30 = 2.53% of data removed
sm.density.compare(POSTTARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, POSTTARGET_GD_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_GD_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_GD_CLEAN$GROUP)))

##descriptives
POSTTARGET_GD.GROUP_MEAN = tapply(POSTTARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_GD_CLEAN$GROUP, POSTTARGET_GD_CLEAN$condition_no), mean)
POSTTARGET_GD.GROUP_SD = tapply(POSTTARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(POSTTARGET_GD_CLEAN$GROUP, POSTTARGET_GD_CLEAN$condition_no), sd)

##transform data for analysis
POSTTARGET_GD_CLEAN$logGD  = log(POSTTARGET_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logGD|GROUP, data = POSTTARGET_GD_CLEAN)
qqmath(~logGD, data = POSTTARGET_GD_CLEAN)
qqmath(~logGD|RECORDING_SESSION_LABEL, data = POSTTARGET_GD_CLEAN)
qqmath(~logGD|stimulus_no, data = POSTTARGET_GD_CLEAN)
sm.density.compare(POSTTARGET_GD_CLEAN$logGD, POSTTARGET_GD_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_GD_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_GD_CLEAN$GROUP)))

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_GD_CLEAN$condition_no) = matrix
contrasts(POSTTARGET_GD_CLEAN$GROUP) <- contr.sdif(2)
lmerGD_POST = lmer(logGD ~ GROUP*condition_no + CENTRED_AGE + (1+ condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)), data =POSTTARGET_GD_CLEAN)                                                                                                            
qqnorm(resid(lmerGD_POST))
sm.density(resid(lmerGD_POST))
sm.density.compare(resid(lmerGD_POST), POSTTARGET_GD_CLEAN$GROUP)
summary(lmerGD_POST)
plot(allEffects(lmerGD_POST))

#######################################Go Past Time###################################

POSTTARGET_GP = POSTTARGET[POSTTARGET$IA_SKIP == 0,]
POSTTARGET_GP <- POSTTARGET_GP[!(is.na(POSTTARGET_GP$IA_REGRESSION_PATH_DURATION)),] #removing any NA's

#checking structure and distribution
str(POSTTARGET_GP)
qqnorm(POSTTARGET_GP$IA_REGRESSION_PATH_DURATION)
qqmath(~IA_REGRESSION_PATH_DURATION|GROUP, data = POSTTARGET_GP)
sm.density.compare(POSTTARGET_GP$IA_REGRESSION_PATH_DURATION, POSTTARGET_GP$GROUP)
legend("topright", levels(POSTTARGET_GP$GROUP), fill=2+(0:nlevels(POSTTARGET_GP$GROUP)))

#removing outliers >2.5sd group/condition mean
mean.matrix.POSTTARGET_GP = tapply(POSTTARGET_GP$IA_REGRESSION_PATH_DURATION, list(POSTTARGET_GP$GROUP, POSTTARGET_GP$condition_no), mean, na.rm = TRUE)
mean.matrix.POSTTARGET_GP
sd.matrix.POSTTARGET_GP = tapply(POSTTARGET_GP$IA_REGRESSION_PATH_DURATION, list(POSTTARGET_GP$GROUP, POSTTARGET_GP$condition_no), sd, na.rm = TRUE)
sd.matrix.POSTTARGET_GP
nr=nrow(POSTTARGET_GP)
for(i in 1:nr){POSTTARGET_GP$mean.sc[i] = mean.matrix.POSTTARGET_GP[POSTTARGET_GP$GROUP[i],POSTTARGET_GP$condition_no[i]]}
for(i in 1:nr){POSTTARGET_GP$sd.sc[i] = sd.matrix.POSTTARGET_GP[POSTTARGET_GP$GROUP[i],POSTTARGET_GP$condition_no[i]]}
for(i in 1:nr) {POSTTARGET_GP$zscore[i] = (POSTTARGET_GP$IA_REGRESSION_PATH_DURATION[i] - POSTTARGET_GP$mean.sc[i])/POSTTARGET_GP$sd.sc[i]}
head(POSTTARGET_GP)
#sink("POSTTARGET_GP_OUTLIERS.txt")
#POSTTARGET_GP[POSTTARGET_GP$zscore > 2.5,]
#sink()
POSTTARGET_GP_CLEAN = POSTTARGET_GP[abs(POSTTARGET_GP$zscore) < 2.5,]
head(POSTTARGET_GP_CLEAN)
#1188-1144 = 44 = (100/1187)*44 = 3.71% of data lost 
sm.density.compare(POSTTARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, POSTTARGET_GP_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_GP_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_GP_CLEAN$GROUP)))

##descriptives
POSTTARGET_GP.GROUP_MEAN = tapply(POSTTARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, list(POSTTARGET_GP_CLEAN$GROUP, POSTTARGET_GP_CLEAN$condition_no), mean)
POSTTARGET_GP.GROUP_SD = tapply(POSTTARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION, list(POSTTARGET_GP_CLEAN$GROUP, POSTTARGET_GP_CLEAN$condition_no), sd)

##transform data for analysis
POSTTARGET_GP_CLEAN$logGP  = log(POSTTARGET_GP_CLEAN$IA_REGRESSION_PATH_DURATION)
qqmath(~logGP|GROUP, data = POSTTARGET_GP_CLEAN)
qqmath(~logGP, data = POSTTARGET_GP_CLEAN)
qqmath(~logGP|RECORDING_SESSION_LABEL, data = POSTTARGET_GP_CLEAN)
qqmath(~logGP|stimulus_no, data = POSTTARGET_GP_CLEAN)
sm.density.compare(POSTTARGET_GP_CLEAN$logGP, POSTTARGET_GP_CLEAN$GROUP)
legend("topright", levels(POSTTARGET_GP_CLEAN$GROUP), fill=2+(0:nlevels(POSTTARGET_GP_CLEAN$GROUP)))

###lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_GP_CLEAN$condition_no) = matrix
contrasts(POSTTARGET_GP_CLEAN$GROUP) <- contr.sdif(2)
lmerGP_POST = lmer(logGP ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (0+ GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)), data =POSTTARGET_GP_CLEAN)                                                                                                            
qqnorm(resid(lmerGP_POST))
sm.density(resid(lmerGP_POST))
sm.density.compare(resid(lmerGP_POST), POSTTARGET_GP_CLEAN$GROUP)
summary(lmerGP_POST)
plot(allEffects(lmerGP_POST))

#########################################Total Time###################################

POSTTARGET_TT = POSTTARGET[POSTTARGET$IA_SKIP == 0,]
POSTTARGET_TT <- POSTTARGET_TT[!(is.na(POSTTARGET_TT$IA_DWELL_TIME)),] #removing any NA's

#checking structure and distribution
str(POSTTARGET_TT)
qqnorm(POSTTARGET_TT$IA_DWELL_TIME)
qqmath(~IA_DWELL_TIME|GROUP, data = POSTTARGET_TT)
sm.density.compare(POSTTARGET_TT$IA_DWELL_TIME, POSTTARGET_TT$GROUP)
legend("topright", levels(POSTTARGET_TT$GROUP), fill=2+(0:nlevels(POSTTARGET_TT$GROUP)))

#removing outliers >2.5sd group/condition mean 
mean.matrix.POSTTARGET_TT = tapply(POSTTARGET_TT$IA_DWELL_TIME, list(POSTTARGET_TT$GROUP, POSTTARGET_TT$condition_no), mean, na.rm = TRUE)
mean.matrix.POSTTARGET_TT
sd.matrix.POSTTARGET_TT = tapply(POSTTARGET_TT$IA_DWELL_TIME, list(POSTTARGET_TT$GROUP, POSTTARGET_TT$condition_no), sd, na.rm = TRUE)
sd.matrix.POSTTARGET_TT
nr=nrow(POSTTARGET_TT)
for(i in 1:nr){POSTTARGET_TT$mean.sc[i] = mean.matrix.POSTTARGET_TT[POSTTARGET_TT$GROUP[i],POSTTARGET_TT$condition_no[i]]}
for(i in 1:nr){POSTTARGET_TT$sd.sc[i] = sd.matrix.POSTTARGET_TT[POSTTARGET_TT$GROUP[i],POSTTARGET_TT$condition_no[i]]}
for(i in 1:nr) {POSTTARGET_TT$zscore[i] = (POSTTARGET_TT$IA_DWELL_TIME[i] - POSTTARGET_TT$mean.sc[i])/POSTTARGET_TT$sd.sc[i]}
head(POSTTARGET_TT)
#sink("POSTTARGET_TT_OUTLIERS.txt")
#POSTTARGET_TT[POSTTARGET_TT$zscore > 2.5,]
#sink()
POSTTARGET_TT_CLEAN = POSTTARGET_TT[abs(POSTTARGET_TT$zscore) < 2.5,]
head(POSTTARGET_TT_CLEAN)
#1188-1150 = 38 = (100/1187)*38= 3.320% of data lost
sm.density.compare(POSTTARGET_TT_CLEAN $IA_DWELL_TIME, POSTTARGET_TT_CLEAN $GROUP)
legend("topright", levels(POSTTARGET_TT_CLEAN $GROUP), fill=2+(0:nlevels(POSTTARGET_TT_CLEAN$GROUP)))

##descriptives
POSTTARGET_TT.GROUP_MEAN = tapply(POSTTARGET_TT_CLEAN$IA_DWELL_TIME, list(POSTTARGET_TT_CLEAN$GROUP, POSTTARGET_TT_CLEAN$condition_no), mean)
POSTTARGET_TT.GROUP_SD = tapply(POSTTARGET_TT_CLEAN$IA_DWELL_TIME, list(POSTTARGET_TT_CLEAN$GROUP, POSTTARGET_TT_CLEAN$condition_no), sd)

##transform data for analysis
POSTTARGET_TT_CLEAN$logTT  = log(POSTTARGET_TT_CLEAN$IA_DWELL_TIME)
qqmath(~logTT|GROUP, data = POSTTARGET_TT_CLEAN)
qqmath(~logTT, data = POSTTARGET_TT_CLEAN)
qqmath(~logTT|RECORDING_SESSION_LABEL, data = POSTTARGET_TT_CLEAN)
qqmath(~logTT|stimulus_no, data = POSTTARGET_TT_CLEAN)
sm.density.compare(POSTTARGET_TT_CLEAN $logTT, POSTTARGET_TT_CLEAN $GROUP)
legend("topright", levels(POSTTARGET_TT_CLEAN $GROUP), fill=2+(0:nlevels(POSTTARGET_TT_CLEAN$GROUP)))

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_TT_CLEAN$condition_no) = matrix
contrasts(POSTTARGET_TT_CLEAN$GROUP) <- contr.sdif(2)
lmerTT_POST = lmer(logTT ~ GROUP*condition_no + CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP*condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=1000000)), data =POSTTARGET_TT_CLEAN)                                                                                                            
qqnorm(resid(lmerTT_POST))
sm.density(resid(lmerTT_POST))
sm.density.compare(resid(lmerTT_POST), POSTTARGET_TT_CLEAN$GROUP)
summary(lmerTT_POST)
plot(allEffects(lmerTT_POST))

#################################################SUPPLEMENTARY ANALYSIS#################################################
############Why do readers with ASD have longer total reading times?

################################################Start region Gaze Duration################################################
##First we double check there was no difference in GD for the start and end regions for ASD ppts 
##If for some reason they took longer to initially process these regions it may result in the inflated reading times we find
START_GD = START[START$IA_SKIP == 0,]
START_GD <- START_GD[!(is.na(START_GD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and distribution
str(START_GD)
str(START_GD$condition_no)
str(START_GD$stimulus_no)
qqnorm(START_GD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = START_GD)
sm.density.compare(START_GD$IA_FIRST_RUN_DWELL_TIME, START_GD$GROUP)
legend("topright", levels(START_GD$GROUP), fill=2+(0:nlevels(START_GD$GROUP)))

#removing any data points >2.5sd group/condition mean
mean.matrix.START_GD = tapply(START_GD$IA_FIRST_RUN_DWELL_TIME, list(START_GD$GROUP, START_GD$condition_no), mean, na.rm = TRUE)
mean.matrix.START_GD
sd.matrix.START_GD = tapply(START_GD$IA_FIRST_RUN_DWELL_TIME, list(START_GD$GROUP, START_GD$condition_no), sd, na.rm = TRUE)
sd.matrix.START_GD
nr=nrow(START_GD)
for(i in 1:nr){START_GD$mean.sc[i] = mean.matrix.START_GD[START_GD$GROUP[i],START_GD$condition_no[i]]}
for(i in 1:nr){START_GD$sd.sc[i] = sd.matrix.START_GD[START_GD$GROUP[i],START_GD$condition_no[i]]}
for(i in 1:nr) {START_GD$zscore[i] = (START_GD$IA_FIRST_RUN_DWELL_TIME[i] - START_GD$mean.sc[i])/START_GD$sd.sc[i]}
head(START_GD)
#sink("START_GD_OUTLIERS.txt")
#START_GD[START_GD$zscore > 2.5,]
#sink()
START_GD_CLEAN = START_GD[abs(START_GD$zscore) < 2.5,]
head(START_GD_CLEAN)
##1465-1425 = 40 = 100/1464*40 = 2.73% of GD data removed

#rechecking distributions
qqnorm(START_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = START_GD_CLEAN)
sm.density.compare(START_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, START_GD_CLEAN$GROUP)
legend("topright", levels(START_GD_CLEAN$GROUP), fill=2+(0:nlevels(START_GD_CLEAN$GROUP)))

##descriptives
START_GD.GROUP_MEAN = tapply(START_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(START_GD_CLEAN$GROUP, START_GD_CLEAN$condition_no), mean)
START_GD.GROUP_SD = tapply(START_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(START_GD_CLEAN$GROUP, START_GD_CLEAN$condition_no), sd)

##transforming for analysis (consistent with all other measures)
START_GD_CLEAN$logGD  = log(START_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logGD|GROUP, data = START_GD_CLEAN)
qqmath(~logGD, data = START_GD_CLEAN)
qqmath(~logGD|RECORDING_SESSION_LABEL, data = START_GD_CLEAN)
sm.density.compare(START_GD_CLEAN $logGD, START_GD_CLEAN $GROUP)
legend("topright", levels(START_GD_CLEAN $GROUP), fill=2+(0:nlevels(START_GD_CLEAN$GROUP)))
qqmath(~logGD|stimulus_no, data = START_GD_CLEAN)

##lme 
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(START_GD_CLEAN$condition_no) = matrix
contrasts(START_GD_CLEAN$GROUP) <- contr.sdif(2)
lmerSTART_GD = lmer(IA_FIRST_RUN_DWELL_TIME~ GROUP*condition_no +CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP*condition_no +CENTRED_AGE|stimulus_no),control=lmerControl(optCtrl=list(maxfun=250000)), data = START_GD_CLEAN)
qqnorm(resid(lmerSTART_GD))
sm.density(resid(lmerSTART_GD))
sm.density.compare(resid(lmerSTART_GD), START_GD_CLEAN$GROUP)
summary(lmerSTART_GD)
plot(allEffects(lmerSTART_GD))

################################################End Gaze Duration################################################
##removing any empty cells and skips
END_GD = END[END$IA_SKIP == 0 ,]
END_GD <- END_GD[!(is.na(END_GD$IA_FIRST_RUN_DWELL_TIME)),] #removing any NA's

#checking structure and distribution
str(END_GD)
str(END_GD$condition_no)
str(END_GD$stimulus_no)
qqnorm(END_GD$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = END_GD)
sm.density.compare(END_GD$IA_FIRST_RUN_DWELL_TIME, END_GD$GROUP)
legend("topright", levels(END_GD$GROUP), fill=2+(0:nlevels(END_GD$GROUP)))

#removing data points >2.5sd away from group/condition mean
mean.matrix.END_GD = tapply(END_GD$IA_FIRST_RUN_DWELL_TIME, list(END_GD$GROUP, END_GD$condition_no), mean, na.rm = TRUE)
mean.matrix.END_GD
sd.matrix.END_GD = tapply(END_GD$IA_FIRST_RUN_DWELL_TIME, list(END_GD$GROUP, END_GD$condition_no), sd, na.rm = TRUE)
sd.matrix.END_GD
nr = nrow(END_GD)
for(i in 1:nr){END_GD$mean.sc[i] = mean.matrix.END_GD[END_GD$GROUP[i],END_GD$condition_no[i]]}
for(i in 1:nr){END_GD$sd.sc[i] = sd.matrix.END_GD[END_GD$GROUP[i],END_GD$condition_no[i]]}
for(i in 1:nr) {END_GD$zscore[i] = (END_GD$IA_FIRST_RUN_DWELL_TIME[i] - END_GD$mean.sc[i])/END_GD$sd.sc[i]}
head(END_GD)
#sink("END_GD_OUTLIERS.txt")
#END_GD[END_GD$zscore > 2.5,]
#sink()
END_GD_CLEAN = END_GD[abs(END_GD$zscore) < 2.5,]
head(END_GD_CLEAN)
##1192-1156 = 36 = 100/1191*36 = 3.02% of GD data removed

#rechecking distributions
qqnorm(END_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~IA_FIRST_RUN_DWELL_TIME|GROUP, data = END_GD_CLEAN)
sm.density.compare(END_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, END_GD_CLEAN$GROUP)
legend("topright", levels(END_GD_CLEAN$GROUP), fill=2+(0:nlevels(END_GD_CLEAN$GROUP)))

##descriptives
END_GD.GROUP_MEAN = tapply(END_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(END_GD_CLEAN$GROUP, END_GD_CLEAN$condition_no), mean)
END_GD.GROUP_SD = tapply(END_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME, list(END_GD_CLEAN$GROUP, END_GD_CLEAN$condition_no), sd)

##transform data for analysis
END_GD_CLEAN$logGD  = log(END_GD_CLEAN$IA_FIRST_RUN_DWELL_TIME)
qqmath(~logGD|GROUP, data = END_GD_CLEAN)
qqmath(~logGD, data = END_GD_CLEAN)
qqmath(~logGD|RECORDING_SESSION_LABEL, data = END_GD_CLEAN)
qqmath(~logGD|stimulus_no, data = END_GD_CLEAN)
sm.density.compare(END_GD_CLEAN$logGD, END_GD_CLEAN$GROUP)
legend("topright", levels(END_GD_CLEAN$GROUP), fill=2+(0:nlevels(END_GD_CLEAN$GROUP)))

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(END_GD_CLEAN$condition_no) = matrix
contrasts(END_GD_CLEAN$GROUP) <- contr.sdif(2)
lmerEND_GD = lmer(logGD~ GROUP*condition_no +CENTRED_AGE + (1 + condition_no|RECORDING_SESSION_LABEL) + (1+ GROUP+condition_no+CENTRED_AGE|stimulus_no),control=lmerControl(optCtrl=list(maxfun=250000)), data = END_GD_CLEAN)
qqnorm(resid(lmerEND_GD))
sm.density(resid(lmerEND_GD))
sm.density.compare(resid(lmerEND_GD), END_GD_CLEAN$GROUP)
summary(lmerEND_GD)
plot(allEffects(lmerEND_GD))

################################################pretarget rereading###############################################

##I have removed skips because I only want this data measure to reflect revisits to a region.
PRETARGET_SPR = PRETARGET[PRETARGET$IA_SKIP == 0,]
PRETARGET_SPR$SPR = PRETARGET_SPR$IA_DWELL_TIME - PRETARGET_SPR$IA_FIRST_RUN_DWELL_TIME #rereading (or second pass) = total time - gaze duration
head(PRETARGET_SPR)
sm.density.compare(PRETARGET_SPR$SPR, PRETARGET_SPR$GROUP)
legend("topright", levels(PRETARGET_SPR$GROUP), fill=2+(0:nlevels(PRETARGET_SPR$GROUP)))

###################################analysing rereading data as proportion (1 = reread, 0 = no rereading)
#how many zeros?
PRETARGET_SPR_0 = PRETARGET_SPR[PRETARGET_SPR$SPR ==0,] ##(100/1366)*753 = 55% of the time no rereading

#Below I make a binomial variable so we can examine the proportion of trials participants reread
PRETARGET_SPR$SPR_PROP<-ifelse(PRETARGET_SPR$SPR==0,0,1)
head(PRETARGET_SPR)
str(PRETARGET_SPR$SPR_PROP)
str(PRETARGET_SPR$condition_no)
str(PRETARGET_SPR$GROUP)

#descriptives
PRETARGET_SPR_PROP_MEAN = tapply(PRETARGET_SPR$SPR_PROP, list(PRETARGET_SPR$GROUP, PRETARGET_SPR$condition_no), mean)
PRETARGET_SPR_PROP_SD = tapply(PRETARGET_SPR$SPR_PROP, list(PRETARGET_SPR$GROUP, PRETARGET_SPR$condition_no), sd)

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(PRETARGET_SPR$condition_no) <- matrix  
contrasts(PRETARGET_SPR$GROUP) <- contr.sdif(2)  
lmerPRETARGET_SPR_PROP = glmer(SPR_PROP ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=glmerControl(optimizer= "bobyqa", optCtrl=list(maxfun=5000000)), family = binomial, data = PRETARGET_SPR)
summary(lmerPRETARGET_SPR_PROP) 

##################################analysing pretarget rereading time

###below I remove zeros and examine the time participants spent rereading, when they revisted a region
PRETARGET_SPR <- PRETARGET_SPR[!(is.na(PRETARGET_SPR$SPR)),]#removing any NA'S
PRETARGET_SPR = PRETARGET_SPR[PRETARGET_SPR$SPR != 0,] ##removing zeros (when participants did not reread)

sm.density.compare(PRETARGET_SPR$SPR, PRETARGET_SPR$GROUP)
legend("topright", levels(PRETARGET_SPR$GROUP), fill=2+(0:nlevels(PRETARGET_SPR$GROUP)))
min(PRETARGET_SPR$SPR)

#removing data points >2.5sd from group/condition mean
mean.matrix.PRETARGET_SPR = tapply(PRETARGET_SPR$SPR, list(PRETARGET_SPR$GROUP, PRETARGET_SPR$condition_no), mean)
mean.matrix.PRETARGET_SPR
sd.matrix.PRETARGET_SPR = tapply(PRETARGET_SPR$SPR, list(PRETARGET_SPR$GROUP, PRETARGET_SPR$condition_no), sd)
sd.matrix.PRETARGET_SPR
nr = nrow(PRETARGET_SPR)
for(i in 1:nr){PRETARGET_SPR$mean.sc[i] = mean.matrix.PRETARGET_SPR[PRETARGET_SPR$GROUP[i],PRETARGET_SPR$condition_no[i]]}
for(i in 1:nr){PRETARGET_SPR$sd.sc[i] = sd.matrix.PRETARGET_SPR[PRETARGET_SPR$GROUP[i],PRETARGET_SPR$condition_no[i]]}
for(i in 1:nr) {PRETARGET_SPR$zscore[i] = (PRETARGET_SPR$SPR[i] - PRETARGET_SPR$mean.sc[i])/PRETARGET_SPR$sd.sc[i]}
head(PRETARGET_SPR)
#sink("PRETARGET_SPR_SPR_OUTLIERS.txt")
#PRETARGET_SPR[PRETARGET_SPR$zscore > 2.5,]
#sink()
PRETARGET_SPR_clean = PRETARGET_SPR[abs(PRETARGET_SPR$zscore) < 2.5,]
head(PRETARGET_SPR_clean)
#613-595= 18 = 100/613*18= 2.94% data lost
sm.density.compare(PRETARGET_SPR_clean$SPR, PRETARGET_SPR_clean$GROUP)
legend("topright", levels(PRETARGET_SPR_clean$GROUP), fill=2+(0:nlevels(PRETARGET_SPR_clean$GROUP)))

#visualising and transforming data
qqnorm(PRETARGET_SPR_clean$SPR)
qqmath(~SPR|GROUP, data = PRETARGET_SPR_clean)
PRETARGET_SPR_clean$logSPR  = log(PRETARGET_SPR_clean$SPR) 
qqmath(~logSPR|GROUP, data = PRETARGET_SPR_clean)
qqmath(~logSPR, data = PRETARGET_SPR_clean)
qqmath(~logSPR|RECORDING_SESSION_LABEL, data = PRETARGET_SPR_clean)
qqmath(~logSPR|stimulus_no, data = PRETARGET_SPR_clean)
sm.density.compare(PRETARGET_SPR_clean$logSPR, PRETARGET_SPR_clean$GROUP)
legend("topright", levels(PRETARGET_SPR_clean$GROUP), fill=2+(0:nlevels(PRETARGET_SPR_clean$GROUP)))

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(PRETARGET_SPR_clean$condition_no) <- matrix  
contrasts(PRETARGET_SPR_clean$GROUP) <- contr.sdif(2)  
lmerPRETARGET_SPR_clean  = lmer(logSPR ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (0 + condition_no+GROUP+CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=5000000)), data = PRETARGET_SPR_clean)
qqnorm(resid(lmerPRETARGET_SPR_clean))
sm.density(resid(lmerPRETARGET_SPR_clean))
sm.density.compare(resid(lmerPRETARGET_SPR_clean), PRETARGET_SPR_clean$GROUP)
summary(lmerPRETARGET_SPR_clean) 
plot(allEffects(lmerPRETARGET_SPR_clean))

#rereading time descriptives
PRETARGET_SPR_clean.GROUP_MEAN = tapply(PRETARGET_SPR_clean$SPR, list(PRETARGET_SPR_clean$GROUP,PRETARGET_SPR_clean$condition), mean)
PRETARGET_SPR_clean.GROUP_SD = tapply(PRETARGET_SPR_clean$SPR, list(PRETARGET_SPR_clean$GROUP, PRETARGET_SPR_clean$condition), sd)

################################################target rereading################################################
TARGET_SPR = TARGET[TARGET$IA_SKIP == 0,]
TARGET_SPR$SPR = TARGET_SPR$IA_DWELL_TIME - TARGET_SPR$IA_FIRST_RUN_DWELL_TIME
TARGET_SPR <- TARGET_SPR[!(is.na(TARGET_SPR$SPR)),]
sm.density.compare(TARGET_SPR$SPR, TARGET_SPR$GROUP)
legend("topright", levels(TARGET_SPR$GROUP), fill=2+(0:nlevels(TARGET_SPR$GROUP)))

###################################analysing data as proportion (1 = reread, 0 = no rereading)
#how many zeros?
TARGET_SPR_0 = TARGET_SPR[TARGET_SPR$SPR ==0,] ##(100/1214)*772 = 64% of the time no rereading

#Below I make a binomial variable so we can examine the proportion of trials participants reread
TARGET_SPR$SPR_PROP<-ifelse(TARGET_SPR$SPR==0,0,1)
head(TARGET_SPR)
str(TARGET_SPR$SPR_PROP)

#decriptives
TARGET_SPR_PROP_MEAN = tapply(TARGET_SPR$SPR_PROP, list(TARGET_SPR$GROUP, TARGET_SPR$condition_no), mean)
TARGET_SPR_PROP_SD = tapply(TARGET_SPR$SPR_PROP, list(TARGET_SPR$GROUP, TARGET_SPR$condition_no), sd)

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(TARGET_SPR$condition_no) <- matrix  
contrasts(TARGET_SPR$GROUP) <- contr.sdif(2)  
lmerTARGET_SPR_PROP = glmer(SPR_PROP ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=glmerControl(optimizer = "bobyqa", optCtrl=list(maxfun=5000000)), family = binomial, data = TARGET_SPR)
summary(lmerTARGET_SPR_PROP) 

##################################Below I analyse data as rereading time

TARGET_SPR = TARGET_SPR[TARGET_SPR$SPR != 0,] 
TARGET_SPR$SPR
sm.density.compare(TARGET_SPR$SPR, TARGET_SPR$GROUP)
legend("topright", levels(TARGET_SPR$GROUP), fill=2+(0:nlevels(TARGET_SPR$GROUP)))

##removing data points >2.5sd away from group/condition mean
mean.matrix.TARGET_SPR = tapply(TARGET_SPR$SPR, list(TARGET_SPR$GROUP, TARGET_SPR$condition_no), mean)
mean.matrix.TARGET_SPR
sd.matrix.TARGET_SPR = tapply(TARGET_SPR$SPR, list(TARGET_SPR$GROUP, TARGET_SPR$condition_no), sd)
sd.matrix.TARGET_SPR
nr = nrow(TARGET_SPR)
for(i in 1:nr){TARGET_SPR$mean.sc[i] = mean.matrix.TARGET_SPR[TARGET_SPR$GROUP[i],TARGET_SPR$condition_no[i]]}
for(i in 1:nr){TARGET_SPR$sd.sc[i] = sd.matrix.TARGET_SPR[TARGET_SPR$GROUP[i],TARGET_SPR$condition_no[i]]}
for(i in 1:nr) {TARGET_SPR$zscore[i] = (TARGET_SPR$SPR[i] - TARGET_SPR$mean.sc[i])/TARGET_SPR$sd.sc[i]}
head(TARGET_SPR)
#sink("TARGET_SPR_SPR_OUTLIERS.txt")
#TARGET_SPR[TARGET_SPR$zscore > 2.5,]
#sink()
TARGET_SPR_clean = TARGET_SPR[abs(TARGET_SPR$zscore) < 2.5,]
head(TARGET_SPR_clean)
#442-425= 17 = 100/442*17= 3.85% DATA LOST
sm.density.compare(TARGET_SPR_clean$SPR, TARGET_SPR_clean$GROUP)
legend("topright", levels(TARGET_SPR_clean$GROUP), fill=2+(0:nlevels(TARGET_SPR$GROUP)))

qqnorm(TARGET_SPR_clean$SPR)
qqmath(~SPR|GROUP, data = TARGET_SPR_clean)
TARGET_SPR_clean$logSPR  = log(TARGET_SPR_clean$SPR)
qqmath(~logSPR|GROUP, data = TARGET_SPR_clean)
qqmath(~logSPR, data = TARGET_SPR_clean)
qqmath(~logSPR|RECORDING_SESSION_LABEL, data = TARGET_SPR_clean)
qqmath(~logSPR|stimulus_no, data = TARGET_SPR_clean)
sm.density.compare(TARGET_SPR_clean$logSPR, TARGET_SPR_clean$GROUP)#transformation makes data bimodal
legend("topright", levels(TARGET_SPR_clean$GROUP), fill=2+(0:nlevels(TARGET_SPR$GROUP)))

##logtransform makes TD sata appear bimodal - will check residuals before examining model output
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(TARGET_SPR_clean$condition_no) <- matrix  
contrasts(TARGET_SPR_clean$GROUP) <- contr.sdif(2)  
lmerTARGET_SPR  = lmer(logSPR ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (1 + GROUP+condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=5000000)), data = TARGET_SPR_clean)
qqnorm(resid(lmerTARGET_SPR)) #residuals look OK
sm.density(resid(lmerTARGET_SPR)) #residuals look OK
sm.density.compare(resid(lmerTARGET_SPR), TARGET_SPR_clean$GROUP)
summary(lmerTARGET_SPR)  #residuals look OK
plot(allEffects(lmerTARGET_SPR))

#descriptives
TARGET_SPR_clean.GROUP_MEAN = tapply(TARGET_SPR_clean$SPR, list(TARGET_SPR_clean$GROUP,TARGET_SPR_clean$condition), mean)
TARGET_SPR_clean.GROUP_SD = tapply(TARGET_SPR_clean$SPR, list(TARGET_SPR_clean$GROUP, TARGET_SPR_clean$condition), sd)

################################################post target rereading################################################
POSTTARGET_SPR = POSTTARGET[POSTTARGET$IA_SKIP == 0,]
POSTTARGET_SPR$SPR = POSTTARGET_SPR$IA_DWELL_TIME - POSTTARGET_SPR$IA_FIRST_RUN_DWELL_TIME

sm.density.compare(POSTTARGET_SPR$SPR, POSTTARGET_SPR$GROUP)
legend("topright", levels(POSTTARGET_SPR$GROUP), fill=2+(0:nlevels(POSTTARGET_SPR$GROUP)))

###################################analysing data as proportion (1 = reread, 0 = no rereading)
#how many zeros?
POSTTARGET_SPR_0 = POSTTARGET_SPR[POSTTARGET_SPR$SPR ==0,] ##(100/1188)*707 = 59% of the time no rereading

#Below I make a binomial variable so we can examine the proportion of trials participants reread
POSTTARGET_SPR$SPR_PROP<-ifelse(POSTTARGET_SPR$SPR==0,0,1)
head(POSTTARGET_SPR)
str(POSTTARGET_SPR$SPR_PROP)

#descriptives
POSTTARGET_SPR_PROP_MEAN = tapply(POSTTARGET_SPR$SPR_PROP, list(POSTTARGET_SPR$GROUP, POSTTARGET_SPR$condition_no), mean)
POSTTARGET_SPR_PROP_SD = tapply(POSTTARGET_SPR$SPR_PROP, list(POSTTARGET_SPR$GROUP, POSTTARGET_SPR$condition_no), sd)

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_SPR$condition_no) <- matrix  
contrasts(POSTTARGET_SPR$GROUP) <- contr.sdif(2)  
lmerPOSTTARGET_SPR_PROP = glmer(SPR_PROP ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=glmerControl(optimizer="bobyqa", optCtrl=list(maxfun=5000000)), family = binomial, data = POSTTARGET_SPR)
summary(lmerPOSTTARGET_SPR_PROP) 

##################################analysing data as rereading time

##below I examine the time spent rereading
POSTTARGET_SPR <- POSTTARGET_SPR[!(is.na(POSTTARGET_SPR$SPR)),]
POSTTARGET_SPR = POSTTARGET_SPR[POSTTARGET_SPR$SPR != 0,] 
POSTTARGET_SPR$SPR
sm.density.compare(POSTTARGET_SPR$SPR, POSTTARGET_SPR$GROUP)
legend("topright", levels(POSTTARGET_SPR$GROUP), fill=2+(0:nlevels(POSTTARGET_SPR$GROUP)))

mean.matrix.POSTTARGET_SPR = tapply(POSTTARGET_SPR$SPR, list(POSTTARGET_SPR$GROUP, POSTTARGET_SPR$condition_no), mean)
mean.matrix.POSTTARGET_SPR
sd.matrix.POSTTARGET_SPR = tapply(POSTTARGET_SPR$SPR, list(POSTTARGET_SPR$GROUP, POSTTARGET_SPR$condition_no), sd)
sd.matrix.POSTTARGET_SPR
nr = nrow(POSTTARGET_SPR)
for(i in 1:nr){POSTTARGET_SPR$mean.sc[i] = mean.matrix.POSTTARGET_SPR[POSTTARGET_SPR$GROUP[i],POSTTARGET_SPR$condition_no[i]]}
for(i in 1:nr){POSTTARGET_SPR$sd.sc[i] = sd.matrix.POSTTARGET_SPR[POSTTARGET_SPR$GROUP[i],POSTTARGET_SPR$condition_no[i]]}
for(i in 1:nr) {POSTTARGET_SPR$zscore[i] = (POSTTARGET_SPR$SPR[i] - POSTTARGET_SPR$mean.sc[i])/POSTTARGET_SPR$sd.sc[i]}
head(POSTTARGET_SPR)
#sink("POSTTARGET_SPR_OUTLIERS.txt")
#POSTTARGET_SPR[POSTTARGET_SPR$zscore > 2.5,]
#sink()
POSTTARGET_SPR_clean = POSTTARGET_SPR[abs(POSTTARGET_SPR$zscore) < 2.5,]
head(POSTTARGET_SPR_clean)
sm.density.compare(POSTTARGET_SPR_clean$SPR, POSTTARGET_SPR_clean$GROUP)
legend("topright", levels(POSTTARGET_SPR_clean$GROUP), fill=2+(0:nlevels(POSTTARGET_SPR_clean$GROUP)))
#100/481*19 = 3.95% data removed

qqnorm(POSTTARGET_SPR_clean$SPR)
qqmath(~SPR|GROUP, data = POSTTARGET_SPR_clean)
POSTTARGET_SPR_clean$logSPR  = log(POSTTARGET_SPR_clean$SPR) ##NOT QUITE
qqmath(~logSPR|GROUP, data = POSTTARGET_SPR_clean)
qqmath(~logSPR, data = POSTTARGET_SPR_clean)
qqmath(~logSPR|RECORDING_SESSION_LABEL, data = POSTTARGET_SPR_clean)
qqmath(~logSPR|stimulus_no, data = POSTTARGET_SPR_clean)
sm.density.compare(POSTTARGET_SPR_clean$logSPR, POSTTARGET_SPR_clean$GROUP)
legend("topright", levels(POSTTARGET_SPR_clean$GROUP), fill=2+(0:nlevels(POSTTARGET_SPR_clean$GROUP)))

#lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
matrix <- ginv(matrix)  
contrasts(POSTTARGET_SPR_clean$condition_no) <- matrix  
contrasts(POSTTARGET_SPR_clean$GROUP) <- contr.sdif(2) 
lmerPOSTTARGET_SPR_clean  = lmer(logSPR ~ GROUP*condition_no + CENTRED_AGE + (1+condition_no|RECORDING_SESSION_LABEL) + (0 + GROUP*condition_no + CENTRED_AGE|stimulus_no), control=lmerControl(optCtrl=list(maxfun=5000000)), data = POSTTARGET_SPR_clean)
qqnorm(resid(lmerPOSTTARGET_SPR_clean))
sm.density(resid(lmerPOSTTARGET_SPR_clean))
sm.density.compare(resid(lmerPOSTTARGET_SPR_clean), POSTTARGET_SPR_clean$GROUP)
summary(lmerPOSTTARGET_SPR_clean) 
plot(allEffects(lmerPOSTTARGET_SPR_clean))

#descriptives
POSTTARGET_SPR_clean.GROUP_MEAN = tapply(POSTTARGET_SPR_clean$SPR, list(POSTTARGET_SPR_clean$GROUP,POSTTARGET_SPR_clean$condition), mean)
POSTTARGET_SPR_clean.GROUP_SD = tapply(POSTTARGET_SPR_clean$SPR, list(POSTTARGET_SPR_clean$GROUP, POSTTARGET_SPR_clean$condition), sd)

#################################################PRETARGET REGRESSIONS OUT#################################################
PRETARGET_RO = PRETARGET[PRETARGET$IA_SKIP == 0,]
PRETARGET_RO <- droplevels(PRETARGET_RO)
str(PRETARGET_RO$IA_REGRESSION_OUT)
PRETARGET_RO$IA_REGRESSION_OUT = as.character(PRETARGET_RO$IA_REGRESSION_OUT)
PRETARGET_RO$IA_REGRESSION_OUT = as.numeric(PRETARGET_RO$IA_REGRESSION_OUT)

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
contrasts(PRETARGET_RO$GROUP) <- contr.sdif(2)  
contrasts(PRETARGET_RO$condition_no) <- matrix  
lmerPRETARGET_RO = glmer(IA_REGRESSION_OUT ~ GROUP*condition_no + CENTRED_AGE + (1|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=glmerControl(optCtrl=list(maxfun=5000000)), family = binomial, data = PRETARGET_RO)
summary(lmerPRETARGET_RO) 

PRETARGET_RO.GROUP_MEAN = tapply(PRETARGET_RO$IA_REGRESSION_OUT, list(PRETARGET_RO$GROUP, PRETARGET_RO$condition), mean)
PRETARGET_RO.GROUP_SD = tapply(PRETARGET_RO$IA_REGRESSION_OUT, list(PRETARGET_RO$GROUP, PRETARGET_RO$condition), sd)

#################################################TARGET REGRESSIONS OUT#################################################
TARGET_RO = TARGET[TARGET$IA_SKIP == 0,]
TARGET_RO <- droplevels(TARGET_RO)
str(TARGET_RO)
TARGET_RO$IA_REGRESSION_OUT = as.character(TARGET_RO$IA_REGRESSION_OUT)
TARGET_RO$IA_REGRESSION_OUT = as.numeric(TARGET_RO$IA_REGRESSION_OUT)

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
contrasts(TARGET_RO $GROUP) <- contr.sdif(2)  
contrasts(TARGET_RO$condition_no) <- matrix  
lmerTARGET_RO  = glmer(IA_REGRESSION_OUT ~ GROUP*condition_no + CENTRED_AGE + (1|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=glmerControl(optimizer="bobyqa",optCtrl=list(maxfun=5000000)), family = binomial, data = TARGET_RO )
summary(lmerTARGET_RO ) 

TARGET_RO.GROUP_MEAN = tapply(TARGET_RO$IA_REGRESSION_OUT, list(TARGET_RO$GROUP, TARGET_RO$condition), mean)
TARGET_RO.GROUP_SD = tapply(TARGET_RO$IA_REGRESSION_OUT, list(TARGET_RO$GROUP, TARGET_RO$condition), sd)

#################################################POST TARGET REGRESSIONS OUT#################################################
POSTTARGET_RO = POSTTARGET[POSTTARGET$IA_SKIP == 0,]
POSTTARGET_RO <- droplevels(POSTTARGET_RO)
str(POSTTARGET_RO)
POSTTARGET_RO$IA_REGRESSION_OUT = as.character(POSTTARGET_RO$IA_REGRESSION_OUT)
POSTTARGET_RO$IA_REGRESSION_OUT = as.numeric(POSTTARGET_RO$IA_REGRESSION_OUT)

##lme
matrix = rbind(c(-.5, 0, .5),
               c(0,-.5,.5)) 
contrasts(POSTTARGET_RO$condition_no) <- matrix  
contrasts(POSTTARGET_RO$GROUP) <- contr.sdif(2)  
lmerPOSTTARGET_RO  = glmer(IA_REGRESSION_OUT ~ GROUP*condition_no + CENTRED_AGE + (1|RECORDING_SESSION_LABEL) + (1|stimulus_no), control=glmerControl(optCtrl=list(maxfun=5000000)), family = binomial, data = POSTTARGET_RO)
summary(lmerPOSTTARGET_RO) 

POSTTARGET_RO.GROUP_MEAN = tapply(POSTTARGET_RO$IA_REGRESSION_OUT, list(POSTTARGET_RO$GROUP, POSTTARGET_RO$condition), mean)
POSTTARGET_RO.GROUP_SD = tapply(POSTTARGET_RO$IA_REGRESSION_OUT, list(POSTTARGET_RO$GROUP, POSTTARGET_RO$condition), sd)

############################################FIGURE########################################
library(ggplot2)

#####Target FFDd
FFD <- data.frame(
  Group = factor(c("TD","TD","TD","ASD","ASD","ASD")),
  Condition = factor(c("Plausible","Implausible","Anomalous","Plausible","Implausible","Anomalous")),
  FFD = c(205, 218, 226,233,225,245),
  SD= c(54, 57, 67,80,69,86),
  N= c(24, 24, 24,22,22,22)
)
FFD
FFD$SE = FFD$SD/(sqrt(FFD$N))
FFD
ggplot(data=FFD, aes(x=Condition, y=FFD, group=Group)) +
  geom_line(aes(linetype=Group), size=1) +
  geom_errorbar(aes(ymin=FFD-SE, ymax=FFD+SE), width=.1) +
    geom_point()+ 
expand_limits(y=200) +    
expand_limits(y=280)+ 
xlab("Sentence Plasuibility") + ylab("First Fixation Duration (ms)") +
  theme_classic()+
  theme(legend.position=c(.9, .6))  

#############clean up

rm(list = ls(all = TRUE))

